@@ -194,7 +194,7 @@ adapt_form_widget (GnomeDbDsnSpec *spec)
 		GtkWidget *wid;
 		GError *error = NULL;
 		
-		dset = GDA_PARAMETER_LIST (gda_parameter_list_new_from_spec (NULL, str, &error));
+		dset = GDA_PARAMETER_LIST (gda_parameter_list_new_from_spec_string (NULL, str, &error));
 		if (dset) {
 			spec->priv->type = PROVIDER_FORM;
 
@@ -360,12 +360,12 @@ params_to_string (GnomeDbDsnSpec *spec)
 
 		param = GDA_PARAMETER (list->data);
 		if (gda_parameter_is_valid (param)) {
-			const GdaValue *value;
+			const GValue *value;
 			value = gda_parameter_get_value (param);
 			str = NULL;
-			if (value && !gda_value_is_null ((GdaValue *) value)) {
+			if (value && !gda_value_is_null ((GValue *) value)) {
 				GdaDataHandler *dh;
-				GdaValueType dtype;
+				GType dtype;
 
 				dtype = gda_parameter_get_gda_type (param);
 				dh = gda_dict_get_default_handler (default_dict, dtype);
