@@ -70,6 +70,7 @@ typedef struct {
 	gboolean               info_shown;
 	gboolean               data_locked; /* TRUE if no modification allowed on that column */
 } ColumnData;
+
 #define COLUMN_DATA(x) ((ColumnData *)(x))
 
 static ColumnData *get_column_data (GnomeDbRawGrid *grid, GdaParameterListGroup *group);
@@ -111,9 +112,54 @@ enum
 {
         PROP_0,
 	PROP_MODEL,
-	PROP_INFO_CELL_VISIBLE
+	PROP_INFO_CELL_VISIBLE,
+	PROP_GLOBAL_ACTIONS_VISIBLE
 };
 
+/*Callbacks */
+
+/*
+ * Real initialization
+ */
+
+static gboolean tree_view_event_cb (GtkWidget *treeview, GdkEvent *event, GnomeDbRawGrid *grid);
+static gint     tree_view_popup_button_pressed_cb (GtkWidget *widget, GdkEventButton *event, 
+						   GnomeDbRawGrid *grid);
+
+static void     tree_view_selection_changed_cb (GtkTreeSelection *selection, GnomeDbRawGrid *grid);
+static void     tree_view_row_activated_cb     (GtkTreeView *tree_view, GtkTreePath *path, 
+						GtkTreeViewColumn *column, GnomeDbRawGrid *grid);
+
+static void action_new_cb (GtkAction *action, GnomeDbRawGrid *grid);
+static void action_delete_cb (GtkAction *action, GnomeDbRawGrid *grid);
+static void action_undelete_cb (GtkAction *action, GnomeDbRawGrid *grid);
+static void action_commit_cb (GtkAction *action, GnomeDbRawGrid *grid);
+static void action_reset_cb (GtkAction *action, GnomeDbRawGrid *grid);
+static void action_first_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
+static void action_prev_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
+static void action_next_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
+static void action_last_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
+
+static GtkActionEntry ui_actions[] = {
+	{ "ActionNew", GTK_STOCK_NEW, "_New", NULL, "Create a new data entry", G_CALLBACK (action_new_cb)},
+	{ "ActionDelete", GTK_STOCK_DELETE, "_Delete", NULL, "Delete the selected entry", G_CALLBACK (action_delete_cb)},
+	{ "ActionUndelete", GTK_STOCK_UNDELETE, "_Undelete", NULL, "Cancels the deletion of the selected entry", 
+	  G_CALLBACK (action_undelete_cb)},
+	{ "ActionCommit", GTK_STOCK_SAVE, "_Commit", NULL, "Commit the latest changes", G_CALLBACK (action_commit_cb)},
+	{ "ActionReset", GTK_STOCK_REFRESH, "_Reset", NULL, "Reset the data", G_CALLBACK (action_reset_cb)},
+	{ "ActionFirstChunck", GTK_STOCK_GOTO_FIRST, "_First chunck", NULL, "Go to first chunck of records", 
+	  G_CALLBACK (action_first_chunck_cb)},
+	{ "ActionLastChunck", GTK_STOCK_GOTO_LAST, "_Last chunck", NULL, "Go to last chunck of records", 
+	  G_CALLBACK (action_last_chunck_cb)},
+	{ "ActionPrevChunck", GTK_STOCK_GO_BACK, "_Previous chunck", NULL, "Go to previous chunck of records", 
+	  G_CALLBACK (action_prev_chunck_cb)},
+	{ "ActionNextChunck", GTK_STOCK_GO_FORWARD, "Ne_xt chunck", NULL, "Go to next chunck of records",
+	  G_CALLBACK (action_next_chunck_cb)}
+};
+
+
+
+
 GType
 gnome_db_raw_grid_get_type (void)
 {
@@ -196,24 +242,50 @@ gnome_db_raw_grid_class_init (GnomeDbRawGridClass * class)
         object_class->set_property = gnome_db_raw_grid_set_property;
         object_class->get_property = gnome_db_raw_grid_get_property;
 	g_object_class_install_property (object_class, PROP_MODEL,
-                                         g_param_spec_pointer ("model", _("Data to display"), NULL,
+                                         g_param_spec_object ("model", _("Data to display"), NULL, GDA_TYPE_DATA_MODEL,
                                                                G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class, PROP_INFO_CELL_VISIBLE,
-                                         g_param_spec_boolean ("info_cell_visible", NULL, NULL, FALSE,
-                                                               G_PARAM_WRITABLE));
+                                         g_param_spec_boolean ("info_cell_visible", NULL, _("Info cell visible"), FALSE,
+                                                               G_PARAM_READABLE | G_PARAM_WRITABLE));
+															   
+	g_object_class_install_property (object_class, PROP_GLOBAL_ACTIONS_VISIBLE,
+                                         g_param_spec_boolean ("global_actions_visible", NULL, _("Global Actions visible"), FALSE,
+                                                               G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 static void
-gnome_db_raw_grid_init (GnomeDbRawGrid *wid)
+gnome_db_raw_grid_init (GnomeDbRawGrid *grid)
 {
-	wid->priv = g_new0 (GnomeDbRawGridPriv, 1);
-	wid->priv->store = NULL;
-	wid->priv->proxy = NULL;
-	wid->priv->default_show_info_cell = TRUE;
-	wid->priv->default_show_global_actions = TRUE;
-	wid->priv->columns_data = NULL;
-	wid->priv->export_type = 2;
-	gnome_db_raw_grid_initialize (wid);
+	GtkTreeView *tree_view;
+	GtkTreeSelection *selection;
+	
+	grid->priv = g_new0 (GnomeDbRawGridPriv, 1);
+	grid->priv->store = NULL;
+	grid->priv->proxy = NULL;
+	grid->priv->default_show_info_cell = TRUE;
+	grid->priv->default_show_global_actions = TRUE;
+	grid->priv->columns_data = NULL;
+	grid->priv->export_type = 2;
+	
+	tree_view = GTK_TREE_VIEW (grid);
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree_view), TRUE);
+	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tree_view), TRUE);
+	g_signal_connect (G_OBJECT (tree_view), "event",
+			  G_CALLBACK (tree_view_event_cb), grid);
+	g_signal_connect (G_OBJECT (tree_view), "button_press_event",
+                          G_CALLBACK (tree_view_popup_button_pressed_cb), grid);
+
+	/* selection and signal handling */
+	selection = gtk_tree_view_get_selection (tree_view);
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
+	g_signal_connect (G_OBJECT (selection), "changed",
+			  G_CALLBACK (tree_view_selection_changed_cb), grid);
+	g_signal_connect (G_OBJECT (tree_view), "row_activated",
+			  G_CALLBACK (tree_view_row_activated_cb), grid);
+
+	/* action group */
+	grid->priv->actions_group = gtk_action_group_new ("Actions");
+	gtk_action_group_add_actions (grid->priv->actions_group, ui_actions, G_N_ELEMENTS (ui_actions), grid);
 }
 
 /**
@@ -275,49 +347,55 @@ gnome_db_raw_grid_set_property (GObject *object,
         if (grid->priv) {
                 switch (param_id) {
 		case PROP_MODEL:
-		{
-			GdaDataModel *model = g_value_get_pointer (value);
-			if (model)
-				g_return_if_fail (GDA_IS_DATA_MODEL (model));
-
-			gnome_db_raw_grid_clean (grid);
-			if (!model)
-				return;
-
-			grid->priv->store = GNOME_DB_DATA_STORE (gnome_db_data_store_new (model));
-			grid->priv->proxy = gnome_db_data_store_get_proxy (grid->priv->store);
-			grid->priv->data_model = gda_data_proxy_get_proxied_model (grid->priv->proxy);
-			
-			gda_object_connect_destroy (grid->priv->proxy,
-						    G_CALLBACK (proxy_destroyed_cb), grid);
-			g_signal_connect (grid->priv->proxy, "sample_changed",
-					  G_CALLBACK (proxy_sample_changed_cb), grid);
-			
-			grid->priv->iter = gda_data_model_create_iter (GDA_DATA_MODEL (grid->priv->proxy));
-			g_signal_connect (grid->priv->iter, "public_data_changed",
-					  G_CALLBACK (paramlist_public_data_changed_cb), grid);
-			gda_data_model_iter_invalidate_contents (grid->priv->iter);
-						
-			gtk_tree_view_set_model ((GtkTreeView *) grid, GTK_TREE_MODEL (grid->priv->store));
-			init_tree_view (grid);
-
-			g_signal_emit_by_name (object, "proxy_changed", grid->priv->proxy);
-			
-			break;
-		}
+			{														
+				GdaDataModel *model = GDA_DATA_MODEL(g_value_get_object (value));
+				if (model)
+					g_return_if_fail (GDA_IS_DATA_MODEL (model));
+	
+				gnome_db_raw_grid_clean (grid);
+				if (!model)
+					return;
+	
+				grid->priv->store = GNOME_DB_DATA_STORE (gnome_db_data_store_new (model));
+				grid->priv->proxy = gnome_db_data_store_get_proxy (grid->priv->store);
+				grid->priv->data_model = gda_data_proxy_get_proxied_model (grid->priv->proxy);
+				
+				gda_object_connect_destroy (grid->priv->proxy,
+								G_CALLBACK (proxy_destroyed_cb), grid);
+				g_signal_connect (grid->priv->proxy, "sample_changed",
+						  G_CALLBACK (proxy_sample_changed_cb), grid);
+				
+				grid->priv->iter = gda_data_model_create_iter (GDA_DATA_MODEL (grid->priv->proxy));
+				g_signal_connect (grid->priv->iter, "public_data_changed",
+						  G_CALLBACK (paramlist_public_data_changed_cb), grid);
+				gda_data_model_iter_invalidate_contents (grid->priv->iter);
+							
+				gtk_tree_view_set_model ((GtkTreeView *) grid, GTK_TREE_MODEL (grid->priv->store));
+				init_tree_view (grid);
+	
+				g_signal_emit_by_name (object, "proxy_changed", grid->priv->proxy);
+				
+				break;
+			}																					
 		case PROP_INFO_CELL_VISIBLE: 
-		{
-			GSList *list = grid->priv->columns_data;
-			gboolean show = g_value_get_boolean (value);
-			grid->priv->default_show_info_cell = show;
-
-			while (list) {
-				COLUMN_DATA (list->data)->info_shown = show;
-				g_object_set (G_OBJECT (COLUMN_DATA (list->data)->info_cell), "visible", show, NULL);
-				list = g_slist_next (list);
+			{
+				GSList *list = grid->priv->columns_data;
+				gboolean show = g_value_get_boolean (value);
+				grid->priv->default_show_info_cell = show;
+	
+				while (list) {
+					COLUMN_DATA (list->data)->info_shown = show;
+					g_object_set (G_OBJECT (COLUMN_DATA (list->data)->info_cell), "visible", show, NULL);
+					list = g_slist_next (list);
+				}
 			}
-		}
-		break;
+			break;
+			
+		case PROP_GLOBAL_ACTIONS_VISIBLE:
+			
+			gtk_action_group_set_visible(grid->priv->actions_group, g_value_get_boolean(value));
+			break;
+		
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -339,6 +417,13 @@ gnome_db_raw_grid_get_property (GObject *object,
 		case PROP_MODEL:
 			g_value_set_pointer (value, grid->priv->data_model);
 			break;
+		case PROP_INFO_CELL_VISIBLE:
+			g_value_set_boolean(value, grid->priv->default_show_info_cell);
+			break;
+		case PROP_GLOBAL_ACTIONS_VISIBLE:
+			g_value_set_boolean(value, grid->priv->default_show_global_actions);
+			break;
+
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -391,71 +476,7 @@ gnome_db_raw_grid_get_selection (GnomeDbRawGrid *grid)
 		return NULL;
 }
 
-/*
- * Real initialization
- */
 
-static gboolean tree_view_event_cb (GtkWidget *treeview, GdkEvent *event, GnomeDbRawGrid *grid);
-static gint     tree_view_popup_button_pressed_cb (GtkWidget *widget, GdkEventButton *event, 
-						   GnomeDbRawGrid *grid);
-
-static void     tree_view_selection_changed_cb (GtkTreeSelection *selection, GnomeDbRawGrid *grid);
-static void     tree_view_row_activated_cb     (GtkTreeView *tree_view, GtkTreePath *path, 
-						GtkTreeViewColumn *column, GnomeDbRawGrid *grid);
-
-static void action_new_cb (GtkAction *action, GnomeDbRawGrid *grid);
-static void action_delete_cb (GtkAction *action, GnomeDbRawGrid *grid);
-static void action_undelete_cb (GtkAction *action, GnomeDbRawGrid *grid);
-static void action_commit_cb (GtkAction *action, GnomeDbRawGrid *grid);
-static void action_reset_cb (GtkAction *action, GnomeDbRawGrid *grid);
-static void action_first_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
-static void action_prev_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
-static void action_next_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
-static void action_last_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
-
-static GtkActionEntry ui_actions[] = {
-	{ "ActionNew", GTK_STOCK_NEW, "_New", NULL, "Create a new data entry", G_CALLBACK (action_new_cb)},
-	{ "ActionDelete", GTK_STOCK_DELETE, "_Delete", NULL, "Delete the selected entry", G_CALLBACK (action_delete_cb)},
-	{ "ActionUndelete", GTK_STOCK_UNDELETE, "_Undelete", NULL, "Cancels the deletion of the selected entry", 
-	  G_CALLBACK (action_undelete_cb)},
-	{ "ActionCommit", GTK_STOCK_SAVE, "_Commit", NULL, "Commit the latest changes", G_CALLBACK (action_commit_cb)},
-	{ "ActionReset", GTK_STOCK_REFRESH, "_Reset", NULL, "Reset the data", G_CALLBACK (action_reset_cb)},
-	{ "ActionFirstChunck", GTK_STOCK_GOTO_FIRST, "_First chunck", NULL, "Go to first chunck of records", 
-	  G_CALLBACK (action_first_chunck_cb)},
-	{ "ActionLastChunck", GTK_STOCK_GOTO_LAST, "_Last chunck", NULL, "Go to last chunck of records", 
-	  G_CALLBACK (action_last_chunck_cb)},
-	{ "ActionPrevChunck", GTK_STOCK_GO_BACK, "_Previous chunck", NULL, "Go to previous chunck of records", 
-	  G_CALLBACK (action_prev_chunck_cb)},
-	{ "ActionNextChunck", GTK_STOCK_GO_FORWARD, "Ne_xt chunck", NULL, "Go to next chunck of records",
-	  G_CALLBACK (action_next_chunck_cb)}
-};
-
-static void 
-gnome_db_raw_grid_initialize (GnomeDbRawGrid *grid)
-{
-	GtkTreeView *tree_view;
-	GtkTreeSelection *selection;
-
-	tree_view = GTK_TREE_VIEW (grid);
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree_view), TRUE);
-	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tree_view), TRUE);
-	g_signal_connect (G_OBJECT (tree_view), "event",
-			  G_CALLBACK (tree_view_event_cb), grid);
-	g_signal_connect (G_OBJECT (tree_view), "button_press_event",
-                          G_CALLBACK (tree_view_popup_button_pressed_cb), grid);
-
-	/* selection and signal handling */
-	selection = gtk_tree_view_get_selection (tree_view);
-	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
-	g_signal_connect (G_OBJECT (selection), "changed",
-			  G_CALLBACK (tree_view_selection_changed_cb), grid);
-	g_signal_connect (G_OBJECT (tree_view), "row_activated",
-			  G_CALLBACK (tree_view_row_activated_cb), grid);
-
-	/* action group */
-	grid->priv->actions_group = gtk_action_group_new ("Actions");
-	gtk_action_group_add_actions (grid->priv->actions_group, ui_actions, G_N_ELEMENTS (ui_actions), grid);
-}
 
 /*
  * creates a new string where underscores '_' are replaced by double underscores '__'
@@ -481,11 +502,11 @@ static void     cell_renderer_info_set_attributes  (GtkTreeViewColumn *tree_colu
 						    GtkTreeModel *tree_model, GtkTreeIter *iter, GnomeDbRawGrid *grid);
 
 static void     data_cell_value_changed (GtkCellRenderer *renderer, const gchar *path, 
-					 const GdaValue *new_value, GnomeDbRawGrid *grid);
+					 const GValue *new_value, GnomeDbRawGrid *grid);
 static void     data_cell_values_changed (GtkCellRenderer *renderer, const gchar *path, 
 					  GSList *new_values, GSList *all_new_values, GnomeDbRawGrid *grid);
 static void     data_cell_status_changed (GtkCellRenderer *renderer, const gchar *path, 
-					  GdaValueAttribute requested_action, GnomeDbRawGrid *grid);
+					  GValueAttribute requested_action, GnomeDbRawGrid *grid);
 
 /*
  * Creates the GtkTreeView's columns, from the grid->priv->store GtkTreeModel
@@ -496,10 +517,12 @@ init_tree_view (GnomeDbRawGrid *grid)
 	gint i;
 	GtkTreeView *tree_view;
 	GSList *list;
+	GdaDict *dict;
 
 	tree_view = GTK_TREE_VIEW (grid);
 
 	/* Creation of the columns in the treeview, to fit the parameters in grid->priv->iter param list */
+	dict = gda_object_get_dict (GDA_OBJECT (grid->priv->iter));
 	list = GDA_PARAMETER_LIST (grid->priv->iter)->groups_list;
 	i = 0;
 	while (list) {
@@ -560,7 +583,7 @@ init_tree_view (GnomeDbRawGrid *grid)
 		}
 		else {
 			/* single direct parameter */
-			GdaValueType gda_type;
+			GType gda_type;
 			gchar *plugin = NULL;
 			gchar *title;
 			
@@ -575,8 +598,8 @@ init_tree_view (GnomeDbRawGrid *grid)
 			if (!title)
 				title = g_strdup (_("No title"));
 			
-			g_object_get (G_OBJECT (param), "handler_plugin", &plugin, NULL);
-			renderer = gnome_db_util_new_cell_renderer (gda_type, plugin);
+			g_object_get (G_OBJECT (param), "entry_plugin", &plugin, NULL);
+			renderer = gnome_db_util_new_cell_renderer (dict, gda_type, plugin);
 			column_data->data_cell = renderer;
 			if (! column_data->data_locked)
 				column_data->data_locked = GDA_PARAMETER_LIST_NODE (group->nodes->data)->hint & 
@@ -605,7 +628,7 @@ init_tree_view (GnomeDbRawGrid *grid)
 		g_object_set_data (G_OBJECT (renderer), "group", group);
 		g_object_set_data (G_OBJECT (column), "group", group);
 
-		/* Adding the GdaValue's information cell as another GtkCellRenderer */
+		/* Adding the GValue's information cell as another GtkCellRenderer */
 		renderer = gnome_db_data_cell_renderer_info_new (grid->priv->store, grid->priv->iter, group);
 		column_data->info_cell = renderer;
 		gtk_tree_view_column_pack_end (column, renderer, FALSE);
@@ -721,7 +744,7 @@ cell_renderer_value_set_attributes (GtkTreeViewColumn *tree_column,
 		/* single direct parameter */
 		gint col;
 		gint offset;
-		GdaValue *value;
+		GValue *value;
 		gint row;
 
 		offset = gda_data_model_get_n_columns (gda_data_proxy_get_proxied_model (grid->priv->proxy));
@@ -812,7 +835,7 @@ static gboolean set_iter_from_path (GnomeDbRawGrid *grid, const gchar *path, Gtk
  * Apply the new_value to the GTkTreeModel (grid->priv->store)
  */
 static void
-data_cell_value_changed (GtkCellRenderer *renderer, const gchar *path, const GdaValue *new_value, GnomeDbRawGrid *grid)
+data_cell_value_changed (GtkCellRenderer *renderer, const gchar *path, const GValue *new_value, GnomeDbRawGrid *grid)
 {
 	GtkTreeIter iter;
 	GdaParameterListGroup *group;
@@ -872,17 +895,17 @@ data_cell_values_changed (GtkCellRenderer *renderer, const gchar *path,
 		while (list) {
 			col = gda_data_model_iter_get_column_for_param (grid->priv->iter, 
 									GDA_PARAMETER_LIST_NODE (params->data)->param);
-			gnome_db_data_store_set_value (grid->priv->store, &iter, col, (GdaValue *)(list->data));
+			gnome_db_data_store_set_value (grid->priv->store, &iter, col, (GValue *)(list->data));
 			list = g_slist_next (list);
 			params = g_slist_next (params);
 		}
 		
 		/* call gda_data_proxy_set_model_row_value() */
 		for (i = 0; i < group->nodes_source->shown_n_cols; i++) {
-			GdaValue *value;
+			GValue *value;
 
 			col = group->nodes_source->shown_cols_index[i];
-			value = (GdaValue *) g_slist_nth_data (all_new_values, col);
+			value = (GValue *) g_slist_nth_data (all_new_values, col);
 			gda_data_proxy_set_model_row_value (grid->priv->proxy, 
 							    group->nodes_source->data_model,
 							    proxy_row, col, value);
@@ -918,7 +941,7 @@ set_iter_from_path (GnomeDbRawGrid *grid, const gchar *path, GtkTreeIter *iter)
  * Actions
  */
 static void
-data_cell_status_changed (GtkCellRenderer *renderer, const gchar *path, GdaValueAttribute requested_action,
+data_cell_status_changed (GtkCellRenderer *renderer, const gchar *path, GValueAttribute requested_action,
 			  GnomeDbRawGrid *grid)
 {
 	GtkTreePath *treepath;
@@ -927,7 +950,7 @@ data_cell_status_changed (GtkCellRenderer *renderer, const gchar *path, GdaValue
 	GtkTreeModel *tree_model;
 	gint col;
 	gint offset;
-	GdaValue *attribute;
+	GValue *attribute;
 
 	offset = gda_data_model_get_n_columns (gda_data_proxy_get_proxied_model (grid->priv->proxy));
 
@@ -942,7 +965,7 @@ data_cell_status_changed (GtkCellRenderer *renderer, const gchar *path, GdaValue
 	}
 	gtk_tree_path_free (treepath);
 	
-	attribute = gda_value_new_uinteger (requested_action);
+	g_value_set_uint (attribute = gda_value_new (G_TYPE_UINT), requested_action);
 	if (group->nodes_source) {
 		/* parameters depending on a GdaDataModel */
 		gint i, proxy_row;
@@ -1015,18 +1038,28 @@ action_delete_cb (GtkAction *action, GnomeDbRawGrid *grid)
 	GtkTreeIter iter;
 	GtkTreeSelection *select;
 	GtkTreeModel *model;
-	GList *sel_rows, *cur_row;
+	GList *sel_rows;
+	GdaDataProxy *proxy;
 	
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (grid));
 	sel_rows = gtk_tree_selection_get_selected_rows (select, &model);
-	cur_row = sel_rows;
-	while (cur_row) {
-		gtk_tree_model_get_iter (model, &iter, (GtkTreePath *) (cur_row->data));
-		gnome_db_data_store_delete (grid->priv->store, &iter);
-		cur_row = g_list_next (cur_row);
+	proxy = gnome_db_data_store_get_proxy (GNOME_DB_DATA_STORE (model));
+
+	/* rem: get the list of selected rows after each row deletion because the data model might have changed and
+	 * row numbers might also have changed */
+	while (sel_rows) {
+		gtk_tree_model_get_iter (model, &iter, (GtkTreePath *) (sel_rows->data));
+		if (!gda_data_proxy_row_is_deleted (proxy, 
+						    gnome_db_data_store_get_row_from_iter (GNOME_DB_DATA_STORE (model), 
+											   &iter))) {
+			gnome_db_data_store_delete (grid->priv->store, &iter);
+			g_list_foreach (sel_rows, (GFunc) gtk_tree_path_free, NULL);
+			g_list_free (sel_rows);
+			sel_rows = gtk_tree_selection_get_selected_rows (select, &model); 
+		}
+		else
+			sel_rows = sel_rows->next;
 	}
-	g_list_foreach (sel_rows, (GFunc) gtk_tree_path_free, NULL);
-	g_list_free (sel_rows);
 }
 
 static void
@@ -1052,7 +1085,12 @@ action_undelete_cb (GtkAction *action, GnomeDbRawGrid *grid)
 static void
 action_commit_cb (GtkAction *action, GnomeDbRawGrid *grid)
 {
-	gda_data_proxy_apply_all_changes (grid->priv->proxy, NULL);
+	GError *error = NULL;
+	if (!gda_data_proxy_apply_all_changes (grid->priv->proxy, &error)) {
+		g_warning (_("ERROR: %s\n"), error && error->message ? error->message : _("No detail"));
+		if (error)
+			g_error_free (error);
+	}
 }
 
 static void
