@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2002 The GNOME Foundation.
+ * Copyright (C) 1999 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  * 	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -23,7 +23,7 @@
 #include <gtk/gtkiconfactory.h>
 #include <gtk/gtkstock.h>
 #include <libgnomedb/gnome-db-stock.h>
-#include "gnome-db-i18n.h"
+#include <glib/gi18n-lib.h>
 
 static GtkStockItem builtin_icons [] = {
 	{ GNOME_DB_STOCK_AGGREGATES, N_("Aggregates"), 0, 0, GETTEXT_PACKAGE },
@@ -90,7 +90,7 @@ get_stock_icons (GtkIconFactory *factory)
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_COMMIT);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-connect_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_CONNECT);
-	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-database_24x24.png",
+	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gda-dict-database_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_DATABASE);
 	add_sized (factory,  LIBGNOMEDB_ICONSDIR "/gnome-db-designer_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_DESIGNER);
@@ -100,7 +100,7 @@ get_stock_icons (GtkIconFactory *factory)
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_NO_TRANSACTION);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-procedures_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_PROCEDURES);
-	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-query_24x24.png",
+	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gda-query_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_QUERY);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-rollback_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_ROLLBACK);
@@ -108,7 +108,7 @@ get_stock_icons (GtkIconFactory *factory)
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_SEQUENCES);
 	add_sized (factory,  LIBGNOMEDB_ICONSDIR "/gnome-db-sql_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_SQL);
-	add_sized (factory,  LIBGNOMEDB_ICONSDIR "/gnome-db-tables_24x24.png",
+	add_sized (factory,  LIBGNOMEDB_ICONSDIR "/gda-dict-tables_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_TABLES);
 	add_sized (factory, LIBGNOMEDB_ICONSDIR "/gnome-db-types_24x24.png",
 		   GTK_ICON_SIZE_BUTTON, GNOME_DB_STOCK_TYPES);
