@@ -1,9 +1,10 @@
 /* GNOME DB library
- * Copyright (C) 1999-2002 The GNOME Foundation.
+ * Copyright (C) 1999 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
  *      Carlos Perell Marn <carlos@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -64,7 +65,7 @@
 #ifdef BUILD_WITH_GNOME
 #include <libgnomeui/gnome-file-entry.h>
 #endif
-#include "gnome-db-i18n.h"
+#include <glib/gi18n-lib.h>
 
 /**
  * gnome_db_new_button_widget
@@ -131,38 +132,6 @@ gnome_db_new_entry_widget (gint max_length, gboolean editable)
 	return entry;
 }
 
-#ifdef BUILD_WITH_GNOME
-/**
- * gnome_db_new_file_entry_widget
- * @history_id:
- * @title:
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_file_entry_widget (const gchar *history_id, const gchar *title)
-{
-	GtkWidget *entry;
-#if GTK_CHECK_VERSION(2,4,0)
-	GValue value = { 0, };
-#endif
-
-	entry = gnome_file_entry_new (history_id, title);
-#if GTK_CHECK_VERSION(2, 4, 0)
-	g_value_init (&value, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&value, TRUE);
-	g_object_set_property (G_OBJECT (entry), "use-filechooser", &value);
-	g_value_reset (&value);
-#endif
-	gtk_widget_show (entry);
-
-	return entry;
-}
-#endif
-
-
 /**
  * gnome_db_new_hbox_widget
  * @homogenous:
@@ -225,24 +194,6 @@ gnome_db_new_notebook_widget (void)
 	return notebook;
 }
 
-/**
- * gnome_db_new_option_menu_widget
- *
- *
- *
- * Returns:
- */
-GtkWidget *
-gnome_db_new_option_menu_widget (void)
-{
-	GtkWidget *option_menu;
-
-	option_menu = gtk_option_menu_new ();
-	gtk_widget_show (option_menu);
-
-	return option_menu;
-}
-
 /**
  * gnome_db_new_scrolled_window_widget
  *
@@ -735,74 +686,20 @@ gnome_db_new_alert (GtkWindow *parent,
 		    const gchar *primary_text,
 		    const gchar *secondary_text)
 {
-	const gchar *stock_id = NULL;
-	gchar *str;
 	GtkWidget *dialog;
-	GtkWidget *image;
-	GtkWidget *label;
-	GtkWidget *hbox;
-	GtkWidget *vbox;
+	gchar *str;
 
-	g_return_val_if_fail (primary_text != NULL, NULL);
-
-	dialog = gtk_dialog_new_with_buttons ("",
-					     parent,
-					     GTK_DIALOG_DESTROY_WITH_PARENT |
-					     GTK_DIALOG_NO_SEPARATOR |
-					     GTK_DIALOG_MODAL,
-					     NULL);
-					     
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 12);
-
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
-			    TRUE, TRUE, 0);
-
-	switch (type) {
-	case GTK_MESSAGE_INFO:
-		stock_id = GTK_STOCK_DIALOG_INFO;
-		break;
-	case GTK_MESSAGE_WARNING:
-		stock_id = GTK_STOCK_DIALOG_WARNING;
-		break;
-	case GTK_MESSAGE_QUESTION:
-		stock_id = GTK_STOCK_DIALOG_QUESTION;
-		break;
-	case GTK_MESSAGE_ERROR:
-		stock_id = GTK_STOCK_DIALOG_ERROR;
-		break;
-	}
-	g_return_val_if_fail (stock_id != NULL, NULL);
-
-	image = gtk_image_new_from_stock (stock_id,
-					  GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-	gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
-
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-
-	label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	str = g_strconcat ("<span weight=\"bold\" size=\"larger\">",
+	str = g_strconcat ("<span weight=\"bold\">",
 			   primary_text,
-			   "</span>",
+			   "</span>\n",
+			   secondary_text,
 			   NULL);
-	gtk_label_set_markup (GTK_LABEL (label), str);
-	g_free (str);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-
-	if (secondary_text != NULL) {
-		label = gtk_label_new (secondary_text);
-		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-		gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-	}
 
+	dialog = gtk_message_dialog_new_with_markup (parent, 
+						     GTK_DIALOG_DESTROY_WITH_PARENT |
+						     GTK_DIALOG_MODAL, type,
+						     GTK_BUTTONS_CLOSE, str);
+	
 	return dialog;
 }
 
@@ -813,7 +710,7 @@ gnome_db_new_alert (GtkWindow *parent,
  *
  */
 void
-gnome_db_show_error (const gchar *format, ...)
+gnome_db_show_error (GtkWindow *parent, const gchar *format, ...)
 {
 	va_list args;
         gchar sz[2048];
@@ -825,36 +722,7 @@ gnome_db_show_error (const gchar *format, ...)
         va_end (args);
 
 	/* create the error message dialog */
-	dialog = gnome_db_new_alert (NULL, GTK_MESSAGE_ERROR, sz, NULL);
-	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
-				      gtk_button_new_from_stock (GTK_STOCK_OK),
-				      GTK_RESPONSE_OK);
-	gtk_widget_show_all (dialog);
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-}
-
-/**
- * gnome_db_show_message
- * @format: Format string.
- * @...:
- *
- * Displays an information message to the user.
- */
-void
-gnome_db_show_message (const gchar *format, ...)
-{
-	va_list args;
-        gchar sz[2048];
-	GtkWidget *dialog;
-
-	/* build the message string */
-        va_start (args, format);
-        vsnprintf (sz, sizeof sz, format, args);
-        va_end (args);
-
-	/* create the info message dialog */
-	dialog = gnome_db_new_alert (NULL, GTK_MESSAGE_INFO, sz, NULL);
+	dialog = gnome_db_new_alert (parent, GTK_MESSAGE_ERROR, _("Error:"), sz);
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
 				      gtk_button_new_from_stock (GTK_STOCK_OK),
 				      GTK_RESPONSE_OK);
