@@ -1,6 +1,6 @@
 /* gnome-db-canvas-query-struct.c
  *
- * Copyright (C) 2002 - 2004 Vivien Malerba
+ * Copyright (C) 2002 - 2006 Vivien Malerba
  * Copyright (C) 2002 Fernando Martins
  *
  * This program is free software; you can redistribute it and/or
@@ -21,23 +21,12 @@
 
 #include <gtk/gtk.h>
 #include "marshal.h"
-#include <libgnomedb/gnome-db-entity.h>
-#include <libgnomedb/gnome-db-query.h>
-#include <libgnomedb/gnome-db-join.h>
-#include <libgnomedb/gnome-db-field.h>
-#include <libgnomedb/gnome-db-qfield.h>
-#include <libgnomedb/gnome-db-qf-field.h>
-#include <libgnomedb/gnome-db-condition.h>
-#include <libgnomedb/gnome-db-target.h>
-#include <libgnomedb/gnome-db-ref-base.h>
-#include <libgnomedb/gnome-db-database.h>
-#include <libgnomedb/gnome-db-table.h>
-#include <libgnomedb/gnome-db-constraint.h>
+#include <libgda/libgda.h>
+#include <glib/gi18n-lib.h>
 #include "gnome-db-canvas-query-struct.h"
 #include "gnome-db-canvas-entity.h"
 #include "gnome-db-canvas-join.h"
 #include "gnome-db-canvas-field.h"
-#include "gnome-db-graph-item.h"
 
 static void gnome_db_canvas_query_struct_class_init (GnomeDbCanvasQueryStructClass * class);
 static void gnome_db_canvas_query_struct_init       (GnomeDbCanvasQueryStruct * canvas);
@@ -47,13 +36,13 @@ static void gnome_db_canvas_query_struct_finalize   (GObject *object);
 /* virtual functions */
 static void       create_canvas_items (GnomeDbCanvas *canvas);
 static void       clean_canvas_items  (GnomeDbCanvas *canvas);
-static void       graph_item_added    (GnomeDbCanvas *canvas, GnomeDbGraphItem *item);
-static void       graph_item_dropped  (GnomeDbCanvas *canvas, GnomeDbGraphItem *item);
+static void       graph_item_added    (GnomeDbCanvas *canvas, GdaGraphItem *item);
+static void       graph_item_dropped  (GnomeDbCanvas *canvas, GdaGraphItem *item);
 static GtkWidget *build_context_menu  (GnomeDbCanvas *canvas);
 static void       set_pixels_per_unit (GnomeDbCanvas *canvas, gdouble n);
 
-static void       query_nullified_cb     (GnomeDbQuery *query, GnomeDbCanvas *canvas);
-static void       query_join_added_cb (GnomeDbQuery *query, GnomeDbJoin *join, GnomeDbCanvas *canvas);
+static void       query_destroyed_cb     (GdaQuery *query, GnomeDbCanvas *canvas);
+static void       query_join_added_cb (GdaQuery *query, GdaQueryJoin *join, GnomeDbCanvas *canvas);
 
 static void       drag_action_dcb     (GnomeDbCanvas *canvas, GnomeDbCanvasItem *from_item, GnomeDbCanvasItem *to_item);
 
@@ -63,10 +52,10 @@ static GObjectClass *parent_class = NULL;
 
 struct _GnomeDbCanvasQueryStructPrivate
 {
-	GnomeDbQuery     *query;
+	GdaQuery     *query;
 	GSList      *ent_items;
-	GHashTable  *hash_targets; /* key = GnomeDbTarget, value = GnomeDbCanvasEntity */
-	GHashTable  *hash_joins; /* key = GnomeDbJoin, value = GnomeDbCanvasJoin */
+	GHashTable  *hash_targets; /* key = GdaQueryTarget, value = GnomeDbCanvasEntity */
+	GHashTable  *hash_joins; /* key = GdaQueryJoin, value = GnomeDbCanvasJoin */
 };
 
 GType
@@ -133,7 +122,7 @@ gnome_db_canvas_query_struct_dispose (GObject *object)
 
 	if (canvas->priv) {
 		if (canvas->priv->query)
-			query_nullified_cb (canvas->priv->query, GNOME_DB_CANVAS (canvas));
+			query_destroyed_cb (canvas->priv->query, GNOME_DB_CANVAS (canvas));
 	}
 
 	/* for the parent class */
@@ -165,14 +154,14 @@ gnome_db_canvas_query_struct_finalize (GObject *object)
 static void
 drag_action_dcb (GnomeDbCanvas *canvas, GnomeDbCanvasItem *from_item, GnomeDbCanvasItem *to_item)
 {
-	GnomeDbField *f_field = NULL, *t_field = NULL;
-	GnomeDbTarget *f_target = NULL, *t_target = NULL;
-	GnomeDbGraphItem *gitem;
+	GdaEntityField *f_field = NULL, *t_field = NULL;
+	GdaQueryTarget *f_target = NULL, *t_target = NULL;
+	GdaGraphItem *gitem;
 	GnomeDbCanvasItem *citem;
-	GnomeDbJoin *join;
-	GnomeDbQuery *query;
-	GnomeDbCondition *cond, *newcond;
-	GnomeDbQfield *qfield;
+	GdaQueryJoin *join;
+	GdaQuery *query;
+	GdaQueryCondition *cond, *newcond;
+	GdaQueryField *qfield;
 	
 	/* fields retreival */
 	if (IS_GNOME_DB_CANVAS_FIELD (from_item))
@@ -186,14 +175,14 @@ drag_action_dcb (GnomeDbCanvas *canvas, GnomeDbCanvasItem *from_item, GnomeDbCan
 	/* targets retreival */
 	citem = (GnomeDbCanvasItem *) gnome_db_canvas_field_get_parent_item (GNOME_DB_CANVAS_FIELD (from_item));
 	gitem = gnome_db_canvas_item_get_graph_item (citem);
-	f_target = (GnomeDbTarget *) gnome_db_graph_item_get_ref_object (gitem);
+	f_target = (GdaQueryTarget *) gda_graph_item_get_ref_object (gitem);
 
 	citem = (GnomeDbCanvasItem *) gnome_db_canvas_field_get_parent_item (GNOME_DB_CANVAS_FIELD (to_item));
 	gitem = gnome_db_canvas_item_get_graph_item (citem);
-	t_target = (GnomeDbTarget *) gnome_db_graph_item_get_ref_object (gitem);
+	t_target = (GdaQueryTarget *) gda_graph_item_get_ref_object (gitem);
 
-	if (!f_target || !IS_GNOME_DB_TARGET (f_target) ||
-	    !t_target || !IS_GNOME_DB_TARGET (t_target))
+	if (!f_target || !GDA_IS_QUERY_TARGET (f_target) ||
+	    !t_target || !GDA_IS_QUERY_TARGET (t_target))
 		return;
 
 	if (f_target == t_target) {
@@ -214,65 +203,67 @@ drag_action_dcb (GnomeDbCanvas *canvas, GnomeDbCanvasItem *from_item, GnomeDbCan
 	}
 
 	query = GNOME_DB_CANVAS_QUERY_STRUCT (canvas)->priv->query;
-	join = gnome_db_query_get_join_by_targets (query, f_target, t_target);
+	join = gda_query_get_join_by_targets (query, f_target, t_target);
 	if (!join) {
 		/* create a join */
-		join = GNOME_DB_JOIN (gnome_db_join_new_with_targets (query, f_target, t_target));
-		gnome_db_join_set_join_type (join, GNOME_DB_JOIN_TYPE_INNER);
-		gnome_db_query_add_join (query, join);
+		join = GDA_QUERY_JOIN (gda_query_join_new_with_targets (query, f_target, t_target));
+		gda_query_join_set_join_type (join, GDA_QUERY_JOIN_TYPE_INNER);
+		gda_query_add_join (query, join);
 		g_object_unref (join);
 	}
 
 	/* add an EQUAL condition */
-	newcond = GNOME_DB_CONDITION (gnome_db_condition_new (query, GNOME_DB_CONDITION_LEAF_EQUAL));
-	qfield = gnome_db_query_get_field_by_ref_field (query, f_target, f_field, GNOME_DB_FIELD_ANY);
+	newcond = GDA_QUERY_CONDITION (gda_query_condition_new (query, GDA_QUERY_CONDITION_LEAF_EQUAL));
+	qfield = gda_query_get_field_by_ref_field (query, f_target, f_field, GDA_ENTITY_FIELD_ANY);
 	if (!qfield) {
-		qfield = GNOME_DB_QFIELD (gnome_db_qf_field_new_with_objects (query, f_target, f_field));
-		gnome_db_qfield_set_visible (qfield, FALSE);
-		gnome_db_entity_add_field (GNOME_DB_ENTITY (query), GNOME_DB_FIELD (qfield));
+		qfield = GDA_QUERY_FIELD (gda_query_field_field_new (query, NULL));
+		g_object_set (G_OBJECT (qfield), "target", f_target, "field", f_field, NULL);
+		gda_query_field_set_visible (qfield, FALSE);
+		gda_entity_add_field (GDA_ENTITY (query), GDA_ENTITY_FIELD (qfield));
 		g_object_unref (qfield);
 	}
-	gnome_db_condition_leaf_set_operator (newcond, GNOME_DB_CONDITION_OP_LEFT, qfield);
+	gda_query_condition_leaf_set_operator (newcond, GDA_QUERY_CONDITION_OP_LEFT, qfield);
 
-	qfield = gnome_db_query_get_field_by_ref_field (query, t_target, t_field, GNOME_DB_FIELD_ANY);
+	qfield = gda_query_get_field_by_ref_field (query, t_target, t_field, GDA_ENTITY_FIELD_ANY);
 	if (!qfield) {
-		qfield = GNOME_DB_QFIELD (gnome_db_qf_field_new_with_objects (query, t_target, t_field));
-		gnome_db_qfield_set_visible (qfield, FALSE);
-		gnome_db_entity_add_field (GNOME_DB_ENTITY (query), GNOME_DB_FIELD (qfield));
+		qfield = GDA_QUERY_FIELD (gda_query_field_field_new (query, NULL));
+		g_object_set (G_OBJECT (qfield), "target", t_target, "field", t_field, NULL);
+		gda_query_field_set_visible (qfield, FALSE);
+		gda_entity_add_field (GDA_ENTITY (query), GDA_ENTITY_FIELD (qfield));
 		g_object_unref (qfield);
 	}
-	gnome_db_condition_leaf_set_operator (newcond, GNOME_DB_CONDITION_OP_RIGHT, qfield);
+	gda_query_condition_leaf_set_operator (newcond, GDA_QUERY_CONDITION_OP_RIGHT, qfield);
 
 	/* integrate newcond in the join's condition */
-	cond = gnome_db_join_get_condition (join);
+	cond = gda_query_join_get_condition (join);
 	if (cond) {
-		if (gnome_db_condition_get_cond_type (cond) != GNOME_DB_CONDITION_NODE_AND) {
-			GnomeDbCondition *cond2;
+		if (gda_query_condition_get_cond_type (cond) != GDA_QUERY_CONDITION_NODE_AND) {
+			GdaQueryCondition *cond2;
 
-			cond2 = GNOME_DB_CONDITION (gnome_db_condition_new (query, GNOME_DB_CONDITION_NODE_AND));
-			g_return_if_fail (gnome_db_condition_node_add_child (cond2, cond, NULL));
-			gnome_db_join_set_condition (join, cond2);
+			cond2 = GDA_QUERY_CONDITION (gda_query_condition_new (query, GDA_QUERY_CONDITION_NODE_AND));
+			g_return_if_fail (gda_query_condition_node_add_child (cond2, cond, NULL));
+			gda_query_join_set_condition (join, cond2);
 			g_object_unref (cond2);
 			cond = cond2;
 		}
 
-		g_return_if_fail (gnome_db_condition_node_add_child (cond, newcond, NULL));
+		g_return_if_fail (gda_query_condition_node_add_child (cond, newcond, NULL));
 		g_object_unref (newcond);
 	}
 	else {
-		gnome_db_join_set_condition (join, newcond);
+		gda_query_join_set_condition (join, newcond);
 		g_object_unref (newcond);
 	}
 
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (query), 0);
+	gda_object_dump (GDA_OBJECT (query), 0);
 #endif
 }
 
 /**
  * gnome_db_canvas_query_struct_new
- * @query: a #GnomeDbQuery object
- * @graph: a #GnomeDbGraph object, or %NULL
+ * @query: a #GdaQuery object
+ * @graph: a #GdaGraph object, or %NULL
  *
  * Creates a new canvas widget to display the targets and joins of @query
  *
@@ -282,25 +273,25 @@ drag_action_dcb (GnomeDbCanvas *canvas, GnomeDbCanvasItem *from_item, GnomeDbCan
  * Returns: a new #GnomeDbCanvasQueryStruct widget
  */
 GtkWidget *
-gnome_db_canvas_query_struct_new (GnomeDbQuery *query, GnomeDbGraph *graph)
+gnome_db_canvas_query_struct_new (GdaQuery *query, GdaGraph *graph)
 {
 	GObject *obj;
 	GnomeDbCanvasQueryStruct *canvas;
 	GSList *joins, *list;
 
-	g_return_val_if_fail (query && IS_GNOME_DB_QUERY (query), NULL);
+	g_return_val_if_fail (query && GDA_IS_QUERY (query), NULL);
 	if (graph) {
-		g_return_val_if_fail (IS_GNOME_DB_GRAPH (graph), NULL);
-		g_return_val_if_fail (gnome_db_base_get_dict (GNOME_DB_BASE (query)) == gnome_db_base_get_dict (GNOME_DB_BASE (graph)), NULL);
+		g_return_val_if_fail (GDA_IS_GRAPH (graph), NULL);
+		g_return_val_if_fail (gda_object_get_dict (GDA_OBJECT (query)) == gda_object_get_dict (GDA_OBJECT (graph)), NULL);
 	}
 
         obj = g_object_new (GNOME_DB_TYPE_CANVAS_QUERY_STRUCT, "aa", FALSE, NULL);
 	gnome_canvas_set_center_scroll_region (GNOME_CANVAS (obj), TRUE);
 	canvas = GNOME_DB_CANVAS_QUERY_STRUCT (obj);
 
-	/* connecting to the GnomeDbQuery */
+	/* connecting to the GdaQuery */
 	canvas->priv->query = query;
-	gnome_db_base_connect_nullify (query, G_CALLBACK (query_nullified_cb), obj);
+	gda_object_connect_destroy (query, G_CALLBACK (query_destroyed_cb), obj);
 	g_signal_connect (G_OBJECT (query), "join_added",
 			  G_CALLBACK (query_join_added_cb), obj);
 
@@ -308,10 +299,10 @@ gnome_db_canvas_query_struct_new (GnomeDbQuery *query, GnomeDbGraph *graph)
 	g_object_set (obj, "graph", graph, NULL);
 
 	/* adding all the joins */
-	joins = gnome_db_query_get_joins (query);
+	joins = gda_query_get_joins (query);
 	list = joins;
 	while (list) {
-		query_join_added_cb (query, (GnomeDbJoin *) (list->data), (GnomeDbCanvas *) obj);
+		query_join_added_cb (query, (GdaQueryJoin *) (list->data), (GnomeDbCanvas *) obj);
 		list = g_slist_next (list);
 	}
 	g_slist_free (joins);
@@ -320,12 +311,12 @@ gnome_db_canvas_query_struct_new (GnomeDbQuery *query, GnomeDbGraph *graph)
 }
 
 static void
-query_nullified_cb (GnomeDbQuery *query, GnomeDbCanvas *canvas)
+query_destroyed_cb (GdaQuery *query, GnomeDbCanvas *canvas)
 {
 	/* disconnecting signals */
 	GNOME_DB_CANVAS_QUERY_STRUCT (canvas)->priv->query = NULL;
 	g_signal_handlers_disconnect_by_func (G_OBJECT (query),
-					      G_CALLBACK (query_nullified_cb), canvas);
+					      G_CALLBACK (query_destroyed_cb), canvas);
 	g_signal_handlers_disconnect_by_func (G_OBJECT (query),
 					      G_CALLBACK (query_join_added_cb), canvas);
 
@@ -334,7 +325,7 @@ query_nullified_cb (GnomeDbQuery *query, GnomeDbCanvas *canvas)
 }
 
 static void
-query_join_added_cb (GnomeDbQuery *query, GnomeDbJoin *join, GnomeDbCanvas *canvas)
+query_join_added_cb (GdaQuery *query, GdaQueryJoin *join, GnomeDbCanvas *canvas)
 {
 	GnomeDbCanvasItem *canvas_join;
 	GnomeCanvasItem *root, *canvas_item;
@@ -354,18 +345,18 @@ query_join_added_cb (GnomeDbQuery *query, GnomeDbJoin *join, GnomeDbCanvas *canv
 }
 
 /*
- * Add all the required GnomeCanvasItem objects for the associated #GnomeDbGraph object 
+ * Add all the required GnomeCanvasItem objects for the associated #GdaGraph object 
  */
 static void
 create_canvas_items (GnomeDbCanvas *canvas)
 {
 	GSList *list, *graph_items;
-	GnomeDbGraph *graph = gnome_db_canvas_get_graph (canvas);
+	GdaGraph *graph = gnome_db_canvas_get_graph (canvas);
 
-	graph_items = gnome_db_graph_get_items (graph);
+	graph_items = gda_graph_get_items (graph);
 	list = graph_items;
 	while (list) {
-		graph_item_added (canvas, GNOME_DB_GRAPH_ITEM (list->data));
+		graph_item_added (canvas, GDA_GRAPH_ITEM (list->data));
 		list = g_slist_next (list);
 	}
 	g_slist_free (graph_items);
@@ -390,13 +381,13 @@ clean_canvas_items (GnomeDbCanvas *canvas)
  */
 static GtkWidget *canvas_entity_popup_func (GnomeDbCanvasEntity *ce);
 static void
-graph_item_added (GnomeDbCanvas *canvas, GnomeDbGraphItem *item)
+graph_item_added (GnomeDbCanvas *canvas, GdaGraphItem *item)
 {
 	GnomeCanvasItem *canvas_item, *root;
-	GnomeDbBase *ref_obj = gnome_db_graph_item_get_ref_object (item);
+	GdaObject *ref_obj = gda_graph_item_get_ref_object (item);
 
 	root = GNOME_CANVAS_ITEM (gnome_canvas_root (GNOME_CANVAS (canvas)));
-	if (IS_GNOME_DB_TARGET (ref_obj)) {
+	if (GDA_IS_QUERY_TARGET (ref_obj)) {
 		/* GnomeDbCanvasEntity for the table */
 		canvas_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
 						     GNOME_DB_TYPE_CANVAS_ENTITY,
@@ -430,23 +421,23 @@ canvas_entity_popup_func (GnomeDbCanvasEntity *ce)
 static void
 popup_func_delete_cb (GtkMenuItem *mitem, GnomeDbCanvasEntity *ce)
 {
-	GnomeDbGraphItem *gitem;
-	GnomeDbTarget *target;
+	GdaGraphItem *gitem;
+	GdaQueryTarget *target;
 #ifdef debug
-	GnomeDbQuery *query;
+	GdaQuery *query;
 #endif
 
 	gitem = gnome_db_canvas_item_get_graph_item (GNOME_DB_CANVAS_ITEM (ce));
-	target = (GnomeDbTarget *) gnome_db_graph_item_get_ref_object (gitem);
+	target = (GdaQueryTarget *) gda_graph_item_get_ref_object (gitem);
 
-	g_assert (target && IS_GNOME_DB_TARGET (target));
+	g_assert (target && GDA_IS_QUERY_TARGET (target));
 #ifdef debug
-	query = gnome_db_target_get_query (target);
+	query = gda_query_target_get_query (target);
 #endif
-	gnome_db_base_nullify (GNOME_DB_BASE (target));
+	gda_object_destroy (GDA_OBJECT (target));
 
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (query), 0);
+	gda_object_dump (GDA_OBJECT (query), 0);
 #endif
 }
 
@@ -454,11 +445,11 @@ popup_func_delete_cb (GtkMenuItem *mitem, GnomeDbCanvasEntity *ce)
  * Remove the GnomeDbCanvasEntity corresponding to the graph item
  */
 static void
-graph_item_dropped (GnomeDbCanvas *canvas, GnomeDbGraphItem *item)
+graph_item_dropped (GnomeDbCanvas *canvas, GdaGraphItem *item)
 {
-	GnomeDbBase *ref_obj = gnome_db_graph_item_get_ref_object (item);
+	GdaObject *ref_obj = gda_graph_item_get_ref_object (item);
 	
-	if (IS_GNOME_DB_TARGET (ref_obj)) {
+	if (GDA_IS_QUERY_TARGET (ref_obj)) {
 		GtkObject *canvas_item = g_hash_table_lookup (GNOME_DB_CANVAS_QUERY_STRUCT (canvas)->priv->hash_targets,
 							      ref_obj);
 		if (canvas_item) {
@@ -475,11 +466,11 @@ build_context_menu (GnomeDbCanvas *canvas)
 	GtkWidget *menu, *mitem, *submenu, *submitem;
 	GSList *tables, *list;
 	GnomeDbCanvasQueryStruct *qstruct = GNOME_DB_CANVAS_QUERY_STRUCT (canvas);
-	GnomeDbRefBase *refbase;
-	GnomeDbDict *dict = gnome_db_base_get_dict (GNOME_DB_BASE (qstruct->priv->query));
+	GdaObjectRef *refbase;
+	GdaDict *dict = gda_object_get_dict (GDA_OBJECT (qstruct->priv->query));
 	gboolean other_tables = FALSE;
 
-	tables = gnome_db_database_get_tables (gnome_db_dict_get_database (dict));
+	tables = gda_dict_database_get_tables (gda_dict_get_database (dict));
 
 	menu = gtk_menu_new ();
 	submitem = gtk_menu_item_new_with_label (_("New target from table"));
@@ -491,17 +482,17 @@ build_context_menu (GnomeDbCanvas *canvas)
 		gtk_widget_show (submenu);
 		
 		/* add a menu item for each table not currently shown displayed.
-		 * WARNING: if a GnomeDbTable is detroyed while that menu is displayed, it can still be selected
+		 * WARNING: if a GdaDictTable is detroyed while that menu is displayed, it can still be selected
 		 * from within the menu even though it will not do anything.
 		 */
 		list = tables;
 		while (list) {
-			mitem = gtk_menu_item_new_with_label (gnome_db_base_get_name (GNOME_DB_BASE (list->data)));
+			mitem = gtk_menu_item_new_with_label (gda_object_get_name (GDA_OBJECT (list->data)));
 			gtk_widget_show (mitem);
 			gtk_menu_append (submenu, mitem);
 			
-			refbase = GNOME_DB_REF_BASE (gnome_db_ref_base_new (dict));
-			gnome_db_ref_base_set_ref_object (refbase, GNOME_DB_BASE (list->data));
+			refbase = GDA_OBJECT_REF (gda_object_ref_new (dict));
+			gda_object_ref_set_ref_object (refbase, GDA_OBJECT (list->data));
 			g_object_set_data_full (G_OBJECT (mitem), "table", refbase, g_object_unref);
 			
 			g_signal_connect (G_OBJECT (mitem), "activate", G_CALLBACK (popup_add_target_cb), canvas);
@@ -521,62 +512,62 @@ build_context_menu (GnomeDbCanvas *canvas)
 static void
 popup_add_target_cb (GtkMenuItem *mitem, GnomeDbCanvasQueryStruct *canvas)
 {
-	GnomeDbRefBase *refbase;
-	GnomeDbBase *ref_obj;
+	GdaObjectRef *refbase;
+	GdaObject *ref_obj;
 
 	refbase = g_object_get_data (G_OBJECT (mitem), "table");
-	ref_obj =  gnome_db_ref_base_get_ref_object (refbase);
+	ref_obj =  gda_object_ref_get_ref_object (refbase);
 
-	if (ref_obj && IS_GNOME_DB_TABLE (ref_obj)) {
-		GnomeDbTable *table = GNOME_DB_TABLE (ref_obj);
-		GnomeDbTarget *target;
-		GnomeDbGraphItem *gitem;
+	if (ref_obj && GDA_IS_DICT_TABLE (ref_obj)) {
+		GdaDictTable *table = GDA_DICT_TABLE (ref_obj);
+		GdaQueryTarget *target;
+		GdaGraphItem *gitem;
 
 		GSList *constraints, *list;
-		GSList *targets = gnome_db_query_get_targets (canvas->priv->query), *tlist;
+		GSList *targets = gda_query_get_targets (canvas->priv->query), *tlist;
 
-		/* actual target and corresponding GnomeDbGraphItem creation */
-		target = GNOME_DB_TARGET (gnome_db_target_new_with_entity (canvas->priv->query, GNOME_DB_ENTITY (table)));
-		gitem = GNOME_DB_GRAPH_ITEM (gnome_db_graph_item_new (gnome_db_base_get_dict (GNOME_DB_BASE (canvas->priv->query)), GNOME_DB_BASE (target)));
-		gnome_db_graph_item_set_position (gitem, GNOME_DB_CANVAS (canvas)->xmouse, GNOME_DB_CANVAS (canvas)->ymouse);
-		gnome_db_graph_add_item (gnome_db_canvas_get_graph (GNOME_DB_CANVAS (canvas)), gitem);
+		/* actual target and corresponding GdaGraphItem creation */
+		target = GDA_QUERY_TARGET (gda_query_target_new (canvas->priv->query, gda_object_get_name (GDA_OBJECT (table))));
+		gitem = GDA_GRAPH_ITEM (gda_graph_item_new (gda_object_get_dict (GDA_OBJECT (canvas->priv->query)), GDA_OBJECT (target)));
+		gda_graph_item_set_position (gitem, GNOME_DB_CANVAS (canvas)->xmouse, GNOME_DB_CANVAS (canvas)->ymouse);
+		gda_graph_add_item (gnome_db_canvas_get_graph (GNOME_DB_CANVAS (canvas)), gitem);
 		g_object_unref (G_OBJECT (gitem));
-		gnome_db_query_add_target (canvas->priv->query, target, NULL);
+		gda_query_add_target (canvas->priv->query, target, NULL);
 		g_object_unref (target);
 		
 		/* using database FK constraints to create joins */
-		constraints = gnome_db_database_get_tables_fk_constraints (gnome_db_dict_get_database (gnome_db_base_get_dict (GNOME_DB_BASE (table))),
+		constraints = gda_dict_database_get_tables_fk_constraints (gda_dict_get_database (gda_object_get_dict (GDA_OBJECT (table))),
 								     table, NULL, FALSE);
 		list = constraints;
 		while (list) {
-			GnomeDbConstraint *cons = GNOME_DB_CONSTRAINT (list->data);
-			GnomeDbTable *otable;
-			GnomeDbTarget *otarget = NULL;
+			GdaDictConstraint *cons = GDA_DICT_CONSTRAINT (list->data);
+			GdaDictTable *otable;
+			GdaQueryTarget *otarget = NULL;
 			gboolean table_is_pkey = TRUE;
 			
-			otable = gnome_db_constraint_get_table (cons);
+			otable = gda_dict_constraint_get_table (cons);
 			if (otable == table) {
 				table_is_pkey = FALSE;
-				otable = gnome_db_constraint_fkey_get_ref_table (cons);
+				otable = gda_dict_constraint_fkey_get_ref_table (cons);
 			}
 			
 			/* find a suitable target to make a join with */
 			tlist = targets;
 			while (tlist && !otarget) {
-				if (gnome_db_target_get_represented_entity (GNOME_DB_TARGET (tlist->data)) == 
-				    (GnomeDbEntity *) otable)
-					otarget = GNOME_DB_TARGET (tlist->data);
+				if (gda_query_target_get_represented_entity (GDA_QUERY_TARGET (tlist->data)) == 
+				    (GdaEntity *) otable)
+					otarget = GDA_QUERY_TARGET (tlist->data);
 				tlist = g_slist_next (tlist);
 			}
 			
 			if (otarget) {
-				GnomeDbJoin *join;
+				GdaQueryJoin *join;
 				
 				/* actual join */
-				join = GNOME_DB_JOIN (gnome_db_join_new_with_targets (canvas->priv->query, otarget, target));
-				gnome_db_join_set_join_type (join, GNOME_DB_JOIN_TYPE_INNER);
-				gnome_db_query_add_join (canvas->priv->query, join);
-				gnome_db_join_set_condition_from_fkcons (join);
+				join = GDA_QUERY_JOIN (gda_query_join_new_with_targets (canvas->priv->query, otarget, target));
+				gda_query_join_set_join_type (join, GDA_QUERY_JOIN_TYPE_INNER);
+				gda_query_add_join (canvas->priv->query, join);
+				gda_query_join_set_condition_from_fkcons (join);
 				g_object_unref (join);
 			}
 			
@@ -586,7 +577,7 @@ popup_add_target_cb (GtkMenuItem *mitem, GnomeDbCanvasQueryStruct *canvas)
 		g_slist_free (targets);
 	}
 
-	/* REM: ref_obj could also be in the future a SELECT #GnomeDbQuery */
+	/* REM: ref_obj could also be in the future a SELECT #GdaQuery */
 }
 
 static void
