@@ -42,7 +42,10 @@
 #include <libgnomedb/data-entries/gnome-db-entry-none.h>
 #include <libgnomedb/data-entries/gnome-db-entry-shell.h>
 #include <libgnomedb/data-entries/gnome-db-entry-string.h>
+#include <libgnomedb/data-entries/gnome-db-entry-common-time.h>
 #include <libgnomedb/data-entries/gnome-db-entry-time.h>
+#include <libgnomedb/data-entries/gnome-db-entry-date.h>
+#include <libgnomedb/data-entries/gnome-db-entry-timestamp.h>
 #include <libgnomedb/data-entries/gnome-db-entry-wrapper.h>
 
 /* widgets and objects */
@@ -52,6 +55,7 @@
 #include <libgnomedb/gnome-db-data-source-selector.h>
 #include <libgnomedb/gnome-db-data-store.h>
 #include <libgnomedb/gnome-db-form.h>
+#include <libgnomedb/gnome-db-data-import.h>
 #include <libgnomedb/gnome-db-data-widget-info.h>
 #include <libgnomedb/gnome-db-dbms-update-viewer.h>
 #include <libgnomedb/gnome-db-dsn-config-druid.h>
@@ -72,6 +76,7 @@
 #include <libgnomedb/gnome-db-stock.h>
 #include <libgnomedb/gnome-db-selector-private.h>
 #include <libgnomedb/gnome-db-selector.h>
+#include <libgnomedb/gnome-db-server-operation.h>
 #include <libgnomedb/gnome-db-sql-console.h>
 
 /* graphs */
