@@ -71,6 +71,10 @@ sel_module_data_types_new (GnomeDbSelector *mgsel, gboolean insert_header, GtkTr
 	return module;
 }
 
+static void local_obj_added_cb (GdaDict *dict, GdaObject *obj, Module *module);
+static void local_obj_removed_cb (GdaDict *dict, GdaObject *obj, Module *module);
+static void local_obj_updated_cb (GdaDict *dict, GdaObject *obj, Module *module);
+
 static GSList *module_data_types_get_objects_list (Module *module);
 static gchar  *module_data_types_get_extended_name (GObject *obj);
 static void
@@ -96,25 +100,48 @@ module_data_types_fill_model (Module *module)
 	name_group_init_model_fill (module, model);
 
 	/* Signals handlers */
-	g_signal_connect (G_OBJECT (dict), "data_type_added",
-			  G_CALLBACK (name_group_obj_added_cb), module);
-	g_signal_connect (G_OBJECT (dict), "data_type_removed",
-			  G_CALLBACK (name_group_obj_removed_cb), module);
-	g_signal_connect (G_OBJECT (dict), "data_type_updated",
-			  G_CALLBACK (name_group_obj_updated_cb), module);
+	g_signal_connect (G_OBJECT (dict), "object_added",
+			  G_CALLBACK (local_obj_added_cb), module);
+	g_signal_connect (G_OBJECT (dict), "object_removed",
+			  G_CALLBACK (local_obj_removed_cb), module);
+	g_signal_connect (G_OBJECT (dict), "object_updated",
+			  G_CALLBACK (local_obj_updated_cb), module);
+
 	g_signal_connect (G_OBJECT (dict), "data_update_started",
 			  G_CALLBACK (name_group_update_started_cb), module);
 	g_signal_connect (G_OBJECT (dict), "data_update_finished",
 			  G_CALLBACK (name_group_update_finished_cb), module);
 }
 
+static void
+local_obj_added_cb (GdaDict *dict, GdaObject *obj, Module *module)
+{
+	if (G_OBJECT_TYPE (obj) == GDA_TYPE_DICT_TYPE)
+		name_group_obj_added_cb (dict, obj, module);
+}
+
+static void
+local_obj_removed_cb (GdaDict *dict, GdaObject *obj, Module *module)
+{
+	if (G_OBJECT_TYPE (obj) == GDA_TYPE_DICT_TYPE)
+		name_group_obj_removed_cb (dict, obj, module);
+}
+
+static void
+local_obj_updated_cb (GdaDict *dict, GdaObject *obj, Module *module)
+{
+	if (G_OBJECT_TYPE (obj) == GDA_TYPE_DICT_TYPE)
+		name_group_obj_updated_cb (dict, obj, module);
+}
+
+
 static GSList *
 module_data_types_get_objects_list (Module *module)
 {
 	g_return_val_if_fail (GROUP_DATA (module)->manager, NULL);
 	g_return_val_if_fail (GDA_IS_DICT (GROUP_DATA (module)->manager), NULL);
 
-	return gda_dict_get_data_types (GDA_DICT (GROUP_DATA (module)->manager));
+	return gda_dict_get_dict_types (GDA_DICT (GROUP_DATA (module)->manager));
 }
 
 static gchar *
@@ -137,11 +164,11 @@ module_data_types_free (Module *module)
 
 	if (dict) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (dict),
-						      G_CALLBACK (name_group_obj_added_cb), module);
+						      G_CALLBACK (local_obj_added_cb), module);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (dict),
-						      G_CALLBACK (name_group_obj_removed_cb), module);
+						      G_CALLBACK (local_obj_removed_cb), module);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (dict),
-						      G_CALLBACK (name_group_obj_updated_cb), module);
+						      G_CALLBACK (local_obj_updated_cb), module);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (dict),
 						      G_CALLBACK (name_group_update_started_cb), module);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (dict),
