@@ -54,9 +54,9 @@ sel_module_onequery_new (GnomeDbSelector *mgsel, gboolean insert_header,
 	GdkPixbuf *pixbuf_target = NULL;
 
 	g_assert (data && GDA_IS_QUERY (data));
-	pixbuf_query = gnome_db_stock_get_icon_pixbuf_file ("gda-query_16x16.png");
-	pixbuf_field = gnome_db_stock_get_icon_pixbuf_file ("gda-entity-field_16x16.png");
-	pixbuf_target = gnome_db_stock_get_icon_pixbuf_file ("gda-dict-table_16x16.png");
+	pixbuf_query = gnome_db_stock_get_icon_pixbuf_file ("gnome-db-query_16x16.png");
+	pixbuf_field = gnome_db_stock_get_icon_pixbuf_file ("gnome-db-field_16x16.png");
+	pixbuf_target = gnome_db_stock_get_icon_pixbuf_file ("gnome-db-table_16x16.png");
 
 	/* module structure */
 	query = GDA_QUERY (data);
@@ -302,7 +302,7 @@ module_onequery_model_store_data (Module *module, GtkTreeIter *iter)
 		field = GDA_QUERY_FIELD (obj);
 
 		/* data type */
-		type = gda_entity_field_get_data_type (GDA_ENTITY_FIELD (obj));
+		type = gda_entity_field_get_dict_type (GDA_ENTITY_FIELD (obj));
 		if (type)
 			str1 = gda_dict_type_get_sqlname (type);
 		else
@@ -325,21 +325,31 @@ module_onequery_model_store_data (Module *module, GtkTreeIter *iter)
 		str1 = gda_object_get_name (GDA_OBJECT (field));
 		if (GDA_IS_QUERY_FIELD_FIELD (obj) && (!str1 || !(*str1))) {
 			gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
-				    NAME_COLUMN, _("Field <no name>"),
-				    -1);
+					    NAME_COLUMN, _("Field <no name>"),
+					    -1);
 		}
 	}
 
 	if (obj && GDA_IS_QUERY (obj)) {
 		const gchar *str1;
+		const gchar *color;
+
+		if (gda_query_get_query_type (GDA_QUERY (obj)) == GDA_QUERY_TYPE_NON_PARSED_SQL)
+			color = GNOME_DB_REFERER_UNKNOWN;
+		else
+			color = gda_referer_activate (GDA_REFERER (obj)) ? GNOME_DB_REFERER_ACTIVE : GNOME_DB_REFERER_INACTIVE;
+		/* set color to NULL since libgda is currently broken regarding objects activation changes */
+		color = NULL;
+
 		gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
 				    EXTRA1_COLUMN, gda_query_get_query_type_string (GDA_QUERY (obj)),
+				    BG_COLOR_COLUMN, color,
 				    -1);
 		str1 = gda_object_get_name (GDA_OBJECT (obj));
 		if (!str1 || !(*str1)) {
 			gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
-				    NAME_COLUMN, _("Query <no name>"),
-				    -1);
+					    NAME_COLUMN, _("Query <no name>"),
+					    -1);
 		}
 	}
 
