@@ -1,6 +1,6 @@
 /* sel-onetarget.c
  *
- * Copyright (C) 2004 Vivien Malerba
+ * Copyright (C) 2004 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,27 +19,19 @@
  */
 
 #include "sel-onetarget.h"
-#include <libgnomedb/libgnomedb.h>
-#include "gnome-db-query.h"
-#include "gnome-db-entity.h"
-#include "gnome-db-qfield.h"
-#include "gnome-db-field.h"
-#include "gnome-db-renderer.h"
-#include "gnome-db-server-data-type.h"
-#include "gnome-db-qf-all.h"
-#include "gnome-db-qf-field.h"
-#include "gnome-db-qf-value.h"
-#include "gnome-db-target.h"
+#include <libgda/libgda.h>
+#include <glib/gi18n-lib.h>
+#include "gnome-db-stock.h"
 
 /*
  *
- * Modules for the fields, targets, joins, etc of a given GnomeDbQuery
+ * Modules for the fields, targets, joins, etc of a given GdaQuery
  *
  */
 typedef struct {
 	ModFlatData  data;
 	GdkPixbuf   *field_pixbuf;
-	GnomeDbTarget    *target;
+	GdaQueryTarget    *target;
 	gboolean    manager_is_represented_entity;
 } ModOnetargetData;
 #define TARGET_DATA(x) ((ModOnetargetData *)(x->mod_data))
@@ -49,7 +41,7 @@ static void         module_onetarget_free (Module *module);
 static const gchar *module_onetarget_col_name (Module *module, guint colno);
 static void         module_onetarget_model_store_data (Module *module, GtkTreeIter *iter);
 static GSList      *module_onetarget_get_objects_list (Module *module);
-static const gchar *module_onetarget_render_qfield_type (GnomeDbQfield *field);
+static const gchar *module_onetarget_render_qfield_type (GdaQueryField *field);
 
 
 static Module *real_sel_module_onetarget_new (GnomeDbSelector *mgsel, gboolean insert_header, 
@@ -74,16 +66,16 @@ real_sel_module_onetarget_new (GnomeDbSelector *mgsel, gboolean insert_header,
 			       GtkTreeIter *iter, gpointer data, gboolean all)
 {
 	Module *module;
-	GnomeDbTarget *target;
+	GdaQueryTarget *target;
 	GdkPixbuf *pixbuf_field = NULL;
-	GnomeDbQuery *query;
+	GdaQuery *query;
 
-	g_assert (data && IS_GNOME_DB_TARGET (data));
+	g_assert (data && GDA_IS_QUERY_TARGET (data));
 	pixbuf_field = gnome_db_stock_get_icon_pixbuf_file ("gnome-db-field_16x16.png");
 
 	/* module structure */
-	target = GNOME_DB_TARGET (data);
-	query = gnome_db_target_get_query (target);
+	target = GDA_QUERY_TARGET (data);
+	query = gda_query_target_get_query (target);
 	module = g_new0 (Module, 1);
 	module->selector = mgsel;
 	module->fill_model = module_onetarget_fill_model;
@@ -103,7 +95,7 @@ real_sel_module_onetarget_new (GnomeDbSelector *mgsel, gboolean insert_header,
 		TARGET_DATA (module)->manager_is_represented_entity = FALSE;
 	}
 	else {
-		FLAT_DATA (module)->manager = G_OBJECT (gnome_db_target_get_represented_entity (target));
+		FLAT_DATA (module)->manager = G_OBJECT (gda_query_target_get_represented_entity (target));
 		TARGET_DATA (module)->manager_is_represented_entity = TRUE;
 	}
 	FLAT_DATA (module)->manager_weak_refed = FALSE;
@@ -122,7 +114,7 @@ real_sel_module_onetarget_new (GnomeDbSelector *mgsel, gboolean insert_header,
 		module->iter = g_new0 (GtkTreeIter, 1);
 		gtk_tree_store_append (GTK_TREE_STORE (model), module->iter, iter);
 		gtk_tree_store_set (GTK_TREE_STORE (model), module->iter, 
-				    NAME_COLUMN, gnome_db_base_get_name (GNOME_DB_BASE (target)), 
+				    NAME_COLUMN, gda_object_get_name (GDA_OBJECT (target)), 
 				    PIXBUF_COLUMN, pixbuf, 
 				    CONTENTS_COLUMN, CONTENTS_TOP_CATEGORY, 
 				    SUB_MODULE_COLUMN, NULL, -1);
@@ -162,14 +154,14 @@ module_onetarget_get_objects_list (Module *module)
 	GSList *retval = NULL;
 
 	if (TARGET_DATA (module)->manager_is_represented_entity) 
-		retval = gnome_db_entity_get_fields (GNOME_DB_ENTITY (FLAT_DATA (module)->manager));
+		retval = gda_entity_get_fields (GDA_ENTITY (FLAT_DATA (module)->manager));
 	else {
 		if ((module->selector->priv->mode & GNOME_DB_SELECTOR_QVIS_FIELDS) ||
 		    (module->selector->priv->mode & GNOME_DB_SELECTOR_QALL_FIELDS)) {
-			GnomeDbQuery *query;
+			GdaQuery *query;
 			
-			query = gnome_db_target_get_query (TARGET_DATA (module)->target);
-			retval = gnome_db_query_get_fields_by_target (query, TARGET_DATA (module)->target, 
+			query = gda_query_target_get_query (TARGET_DATA (module)->target);
+			retval = gda_query_get_fields_by_target (query, TARGET_DATA (module)->target, 
 								module->selector->priv->mode & GNOME_DB_SELECTOR_QVIS_FIELDS);
 		}
 	}
@@ -241,23 +233,23 @@ module_onetarget_model_store_data (Module *module, GtkTreeIter *iter)
 	model = module->selector->priv->model;
 	gtk_tree_model_get (model, iter, OBJ_COLUMN, &obj, -1);
 
-	if (obj && IS_GNOME_DB_QFIELD (obj)) {
-		GnomeDbQfield *field;
+	if (obj && GDA_IS_QUERY_FIELD (obj)) {
+		GdaQueryField *field;
 		const gchar *str1, *str2;
 		gchar *str3;
-		GnomeDbServerDataType *type;
+		GdaDictType *type;
 		
-		field = GNOME_DB_QFIELD (obj);
+		field = GDA_QUERY_FIELD (obj);
 
 		/* data type */
-		type = gnome_db_field_get_data_type (GNOME_DB_FIELD (obj));
+		type = gda_entity_field_get_dict_type (GDA_ENTITY_FIELD (obj));
 		if (type)
-			str1 = gnome_db_server_data_type_get_sqlname (type);
+			str1 = gda_dict_type_get_sqlname (type);
 		else
 			str1 = _("-");
 		/* other */
-		str2 = module_onetarget_render_qfield_type (GNOME_DB_QFIELD (obj));
-		str3 = gnome_db_renderer_render_as_str (GNOME_DB_RENDERER (obj), NULL);
+		str2 = module_onetarget_render_qfield_type (GDA_QUERY_FIELD (obj));
+		str3 = gda_renderer_render_as_str (GDA_RENDERER (obj), NULL);
 		
 		gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
 				    EXTRA1_COLUMN, str1,
@@ -268,7 +260,7 @@ module_onetarget_model_store_data (Module *module, GtkTreeIter *iter)
 		if (str3)
 			g_free (str3);
 
-		str1 = gnome_db_base_get_name (GNOME_DB_BASE (field));
+		str1 = gda_object_get_name (GDA_OBJECT (field));
 		if (!str1 || !(*str1)) {
 			gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
 				    NAME_COLUMN, _("Field <no name>"),
@@ -278,16 +270,16 @@ module_onetarget_model_store_data (Module *module, GtkTreeIter *iter)
 }
 
 static const gchar *
-module_onetarget_render_qfield_type (GnomeDbQfield *field)
+module_onetarget_render_qfield_type (GdaQueryField *field)
 {
 	GType ftype = G_OBJECT_TYPE (field);
 
-	if (ftype == GNOME_DB_TYPE_QF_ALL)
+	if (ftype == GDA_TYPE_QUERY_FIELD_ALL)
 		return _("entity.*");
-	if (ftype == GNOME_DB_TYPE_QF_FIELD)
+	if (ftype == GDA_TYPE_QUERY_FIELD_FIELD)
 		return _("entity.field");
-	if (ftype == GNOME_DB_TYPE_QF_VALUE) {
-		if (gnome_db_qf_value_is_parameter (GNOME_DB_QF_VALUE (field)))
+	if (ftype == GDA_TYPE_QUERY_FIELD_VALUE) {
+		if (gda_query_field_value_is_parameter (GDA_QUERY_FIELD_VALUE (field)))
 			return _("parameter");
 		else
 			return _("value");
