@@ -267,7 +267,7 @@ utility_proxy_compute_values_for_group (GdaParameterListGroup *group, GnomeDbDat
 	offset = gda_data_proxy_get_proxied_model_n_cols (proxy);
 	if (!model_values) {
 		GSList *list;
-		GdaValue *value;
+		GValue *value;
 
 		list = group->nodes;
 		while (list) {
@@ -284,7 +284,7 @@ utility_proxy_compute_values_for_group (GdaParameterListGroup *group, GnomeDbDat
 	else {
 		gint col, i, proxy_row;
 		GdaParameterListSource *source;
-		const GdaValue *value;
+		const GValue *value;
 		gboolean slow_way = FALSE;
 		gboolean ret_null = FALSE;
 
@@ -295,7 +295,7 @@ utility_proxy_compute_values_for_group (GdaParameterListGroup *group, GnomeDbDat
 			if (!slow_way) {
 				value = gda_data_proxy_get_model_row_value (proxy, source->data_model, proxy_row, col);
 				if (value)
-					retval = g_list_append (retval, (GdaValue *) value);
+					retval = g_list_append (retval, (GValue *) value);
 				else {
 					if (gda_data_proxy_get_assigned_model_col (proxy, source->data_model, col) < 0)
 						slow_way = TRUE;
@@ -322,7 +322,7 @@ utility_proxy_compute_values_for_group (GdaParameterListGroup *group, GnomeDbDat
 					cols_index [j] = GDA_PARAMETER_LIST_NODE (list->data)->source_column;
 					gtk_tree_model_get (GTK_TREE_MODEL (store), tree_iter,
 							    colno, &value, -1);
-					key_values = g_slist_append (key_values, (GdaValue *) value);
+					key_values = g_slist_append (key_values, (GValue *) value);
 					list = g_slist_next (list);
 					j++;
 				}
@@ -332,7 +332,7 @@ utility_proxy_compute_values_for_group (GdaParameterListGroup *group, GnomeDbDat
 				if (row >= 0) {
 					value = gda_data_model_get_value_at (GDA_DATA_MODEL (source->data_model),
 									     col, row);
-					retval = g_list_append (retval, (GdaValue *) value);
+					retval = g_list_append (retval, (GValue *) value);
 				}
 				else {
 					g_warning ("Could not find requested value in restricting data model");
@@ -343,7 +343,7 @@ utility_proxy_compute_values_for_group (GdaParameterListGroup *group, GnomeDbDat
 						gchar *str;
 						
 						if (value) {
-							str = gda_value_stringify ((GdaValue *) list->data);
+							str = gda_value_stringify ((GValue *) list->data);
 							g_print ("/%s @col %d", str, cols_index [j]);
 							g_free (str);
 						}
