@@ -1,41 +1,7 @@
+#include <glib/gi18n-lib.h>
 #include <libgnomedb/libgnomedb.h>
 #include <gtk/gtk.h>
 
-static const gchar *my_gda_type_to_string (GdaValueType type)
-{
-	return gda_type_to_string (type);
-	
-	switch (type) {
-        case GDA_VALUE_TYPE_NULL : return "Null";
-        case GDA_VALUE_TYPE_BIGINT : return "Bigint";
-        case GDA_VALUE_TYPE_BIGUINT : return "Biguint";
-        case GDA_VALUE_TYPE_BINARY : return "Binary";
-        case GDA_VALUE_TYPE_BOOLEAN : return "Boolean";
-        case GDA_VALUE_TYPE_DATE : return "Date";
-        case GDA_VALUE_TYPE_DOUBLE : return "Double";
-        case GDA_VALUE_TYPE_GEOMETRIC_POINT : return "Point";
-	case GDA_VALUE_TYPE_GOBJECT : return "GObject";
-        case GDA_VALUE_TYPE_INTEGER : return "Integer";
-        case GDA_VALUE_TYPE_LIST : return "List";
-        case GDA_VALUE_TYPE_MONEY : return "Money";
-        case GDA_VALUE_TYPE_NUMERIC : return "Numeric";
-        case GDA_VALUE_TYPE_SINGLE : return "Single";
-        case GDA_VALUE_TYPE_SMALLINT : return "Smallint";
-        case GDA_VALUE_TYPE_SMALLUINT : return "Smalluint";
-        case GDA_VALUE_TYPE_STRING : return "String";
-        case GDA_VALUE_TYPE_TIME : return "Time";
-        case GDA_VALUE_TYPE_TIMESTAMP : return "Timestamp";
-        case GDA_VALUE_TYPE_TINYINT : return "Tinyint";
-        case GDA_VALUE_TYPE_TINYUINT : return "Tinyuint";
-        case GDA_VALUE_TYPE_TYPE : return "GdaType";
-        case GDA_VALUE_TYPE_UINTEGER : return "UInteger";
-        default:
-		break;
-        }
-
-        return "???";
-}
-
 static gboolean delete_event( GtkWidget *widget,
                               GdkEvent  *event,
                               gpointer   data )
@@ -52,27 +18,70 @@ static void destroy( GtkWidget *widget,
 }
 
 GtkWidget *build_menu (GtkWidget *mainwin, GtkWidget *top_nb);
-GtkWidget *build_main (GnomeDbDict *dict, GnomeDbDataHandler *dh, GdaValueType type);
+GtkWidget *build_main (GdaDict *dict, GdaDataHandler *dh, GType type);
 
+static guint
+gtype_hash (gconstpointer key)
+{
+	return (guint) key;
+}
+
+static gboolean 
+gtype_equal (gconstpointer a, gconstpointer b)
+{
+	return (GType) a == (GType) b ? TRUE : FALSE;
+}
+
+GdaDataHandler* 
+get_handler (GType for_type)
+{
+	static GHashTable *hash = NULL;
+	if (!hash) {
+		hash = g_hash_table_new_full (gtype_hash, gtype_equal, 
+					      NULL, (GDestroyNotify) g_object_unref);
+
+		g_hash_table_insert (hash, (gpointer) G_TYPE_INT64, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_UINT64, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) GDA_TYPE_BINARY, gda_handler_bin_new ());
+		g_hash_table_insert (hash, (gpointer) GDA_TYPE_BLOB, gda_handler_bin_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_BOOLEAN, gda_handler_boolean_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_DATE, gda_handler_time_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_DOUBLE, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_INT, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) GDA_TYPE_NUMERIC, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_FLOAT, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) GDA_TYPE_SHORT, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) GDA_TYPE_USHORT, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_STRING, gda_handler_string_new ());
+		g_hash_table_insert (hash, (gpointer) GDA_TYPE_TIME, gda_handler_time_new ());
+		g_hash_table_insert (hash, (gpointer) GDA_TYPE_TIMESTAMP, gda_handler_time_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_CHAR, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_UCHAR, gda_handler_numerical_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_ULONG, gda_handler_type_new ());
+		g_hash_table_insert (hash, (gpointer) G_TYPE_UINT, gda_handler_numerical_new ());		
+	}
+
+	return g_hash_table_lookup (hash, (gpointer) for_type);
+}
 
 int 
 main (int argc, char **argv)
 {
 	GtkWidget *mainwin, *vbox, *wid, *nb, *label, *menu, *top_nb;
-	GnomeDbDict *dict;
-	GnomeDbServer *srv;
+	GdaDict *dict;
 	GSList *plugins, *list;
-	GdaValueType type;
-	GnomeDbDataHandler *dh;
+	GType type;
+	GdaDataHandler *dh;
+	gint i;
 
 	/* Initialize i18n support */
 	gtk_set_locale ();
 	
 	/* Initialize the widget set */
-	gtk_init (&argc, &argv);
+	gnome_db_init ("test-handlers", "", argc, argv);
 
 	/* tested objects */
-	dict = GNOME_DB_DICT (gnome_db_dict_new ());
+	dict = GDA_DICT (gda_dict_new ());
 
 	/* Create the main window */
 	mainwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -95,8 +104,6 @@ main (int argc, char **argv)
 	gtk_box_pack_start (GTK_BOX (vbox), menu, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), top_nb, TRUE, TRUE, 0);
 
-
-
 	/*
 	 * Default handlers
 	 */
@@ -106,10 +113,10 @@ main (int argc, char **argv)
 
 	label = gtk_label_new("");
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_label_set_markup (GTK_LABEL (label), "<b>Default data handlers:</b>\n"
+	gtk_label_set_markup (GTK_LABEL (label), "<b>Default data entries:</b>\n"
 			      "This test displays GnomeDbDataEntry widgets and helpers to test "
 			      "them in pages of a notebook. Each page presents the default "
-			      "data handler for the corresponding gda type.");
+			      "data entry for the corresponding data type.");
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 5);
 	gtk_widget_show (label);
 
@@ -119,16 +126,20 @@ main (int argc, char **argv)
 	gtk_widget_show (nb);
 
 	/* populating the notebook */
-	srv = gnome_db_dict_get_server (dict);
-	for (type = GDA_VALUE_TYPE_BIGINT; type < GDA_VALUE_TYPE_UNKNOWN; type ++) {
-		dh = gnome_db_server_get_handler_by_gda (srv, type);
+	GType tested_gtypes [] = {G_TYPE_INT64, G_TYPE_UINT64, GDA_TYPE_BINARY, G_TYPE_BOOLEAN, GDA_TYPE_BLOB, G_TYPE_DATE, G_TYPE_DOUBLE,
+				  GDA_TYPE_GEOMETRIC_POINT, G_TYPE_OBJECT, G_TYPE_INT, GDA_TYPE_LIST, 
+				  GDA_TYPE_NUMERIC, G_TYPE_FLOAT, GDA_TYPE_SHORT, GDA_TYPE_USHORT, G_TYPE_STRING, 
+				  GDA_TYPE_TIME, GDA_TYPE_TIMESTAMP, G_TYPE_CHAR, G_TYPE_UCHAR, G_TYPE_UINT};
+
+	for (i = 0; i < sizeof (tested_gtypes) / sizeof (GType); i++) {
+		type = tested_gtypes [i];
+		dh = get_handler (type);
 		wid = build_main (dict, dh, type);
 		gtk_widget_show (wid);
-		label = gtk_label_new (my_gda_type_to_string (type));
+		label = gtk_label_new (gda_type_to_string (type));
 		gtk_notebook_append_page (GTK_NOTEBOOK (nb), wid, label);
 	}
 
-
 	/*
 	 * Plugins page 
 	 */
@@ -138,11 +149,10 @@ main (int argc, char **argv)
 
 	label = gtk_label_new("");
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_label_set_markup (GTK_LABEL (label), "<b>Plugin data handlers:</b>\n"
+	gtk_label_set_markup (GTK_LABEL (label), "<b>Plugin data entries:</b>\n"
 			      "This test displays GnomeDbDataEntry widgets and helpers to test "
 			      "them in pages of a notebook. Each page tests a plugin for a given "
-			      "gda type (there can be several pages for a plugin if the plugin "
-			      "data handler accepts more than one gda type.");
+			      "data type");
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 5);
 	gtk_widget_show (label);
 
@@ -152,29 +162,28 @@ main (int argc, char **argv)
 	gtk_widget_show (nb);
 
 	/* populating the notebook */
-	srv = gnome_db_dict_get_server (dict);
-	plugins = gnome_db_server_get_plugin_handlers (srv);
-	list = plugins;
-	while (list) {
-		gint i, nbt;
-		gchar *str;
+	/* plugins = gda_connection_MIG_get_plugin_handlers (srv); */
+/* 	list = plugins; */
+/* 	while (list) { */
+/* 		gint i, nbt; */
+/* 		gchar *str; */
 
-		dh = GNOME_DB_DATA_HANDLER (list->data);
-		nbt = gnome_db_data_handler_get_nb_gda_types (dh);
-		for (i=0; i<nbt; i++) {
-			type = gnome_db_data_handler_get_gda_type_index (dh, i);
-			wid = build_main (dict, dh, type);
-			gtk_widget_show (wid);
-			str = g_strdup_printf ("%s\n(%s)", gnome_db_data_handler_get_plugin_name (dh),
-					       my_gda_type_to_string (type));
-			label = gtk_label_new (str);
-			gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-			g_free (str);
-			gtk_notebook_append_page (GTK_NOTEBOOK (nb), wid, label);
-		}
-		list = g_slist_next (list);
-	}
-	g_slist_free (plugins);
+/* 		dh = GDA_DATA_HANDLER (list->data); */
+/* 		nbt = gda_data_handler_get_nb_gda_types (dh); */
+/* 		for (i=0; i<nbt; i++) { */
+/* 			type = gda_data_handler_get_gda_type_index (dh, i); */
+/* 			wid = build_main (dict, dh, type); */
+/* 			gtk_widget_show (wid); */
+/* 			str = g_strdup_printf ("%s\n(%s)", gda_data_handler_get_plugin_name (dh), */
+/* 					       gda_type_to_string (type)); */
+/* 			label = gtk_label_new (str); */
+/* 			gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5); */
+/* 			g_free (str); */
+/* 			gtk_notebook_append_page (GTK_NOTEBOOK (nb), wid, label); */
+/* 		} */
+/* 		list = g_slist_next (list); */
+/* 	} */
+/* 	g_slist_free (plugins); */
 		
 
 
@@ -196,15 +205,13 @@ void actions_toggled_cb (GtkToggleButton *button, GtkWidget *entry);
 void orig_clicked_cb (GtkButton *button, GtkWidget *entry);
 void default_clicked_cb (GtkButton *button, GtkWidget *entry);
 GtkWidget *
-build_main (GnomeDbDict *dict, GnomeDbDataHandler *dh, GdaValueType type)
+build_main (GdaDict *dict, GdaDataHandler *dh, GType type)
 {
-	GnomeDbServer *srv;
 	GtkWidget *wid, *label, *table, *button, *bbox, *entry, *vbox;
 	GString *string;
 	
 	vbox = gtk_vbox_new (FALSE, 0);
 
-	srv = gnome_db_dict_get_server (dict);
 	table = gtk_table_new (7, 2, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 5);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 5);
@@ -212,20 +219,12 @@ build_main (GnomeDbDict *dict, GnomeDbDataHandler *dh, GdaValueType type)
 
 	/* explain top label */
 	string = g_string_new ("");
-	g_string_append_printf (string, "<b>Description:</b> %s\n",
-				gnome_db_data_handler_get_descr (dh));
-	g_string_append_printf (string, "<b>Details:</b> %s\n",
-				gnome_db_data_handler_get_descr_detail (dh));
-	g_string_append_printf (string, "<b>Version:</b> %s\n",
-				gnome_db_data_handler_get_version (dh));
-	g_string_append_printf (string, "<b>Key:</b> %s\n",
-				gnome_db_data_handler_get_key (dh));
-	if (gnome_db_data_handler_is_plugin (dh)) {
-		g_string_append_printf (string, "<b>Plugin Name:</b> %s\n"
-					"<b>Plugin File:</b> %s\n",
-					gnome_db_data_handler_get_plugin_name (dh),
-					gnome_db_data_handler_get_plugin_file (dh));
-	}
+	if (dh)
+		g_string_append_printf (string, "<b>Description:</b> %s\n",
+					gda_data_handler_get_descr (dh));
+	else
+		g_string_append_printf (string, "<b>Description:</b> %s\n",
+					_("No GdaDataHandler available for this type"));
 	label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_label_set_markup (GTK_LABEL (label), string->str);
@@ -234,7 +233,7 @@ build_main (GnomeDbDict *dict, GnomeDbDataHandler *dh, GdaValueType type)
 	gtk_widget_show (label);
 
 	/* widget being tested */
-	wid = GTK_WIDGET (gnome_db_data_handler_get_entry_from_value (dh, NULL, type));
+	wid = GTK_WIDGET (gnome_db_util_new_data_entry (NULL, type, NULL));
 	if (gnome_db_data_entry_expand_in_layout (GNOME_DB_DATA_ENTRY (wid)))
 		gtk_table_attach_defaults (GTK_TABLE (table), wid, 0, 2, 1, 2);
 	else
@@ -277,7 +276,7 @@ build_main (GnomeDbDict *dict, GnomeDbDataHandler *dh, GdaValueType type)
 	gtk_container_add (GTK_CONTAINER (bbox), button);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				      gnome_db_data_entry_get_attributes (GNOME_DB_DATA_ENTRY (wid)) & 
-				      GNOME_DB_VALUE_CAN_BE_NULL);
+				      GDA_VALUE_ATTR_CAN_BE_NULL);
 
 	button = gtk_toggle_button_new_with_label (_("DEFAULT ok"));
 	g_signal_connect (G_OBJECT (button), "toggled",
@@ -285,7 +284,7 @@ build_main (GnomeDbDict *dict, GnomeDbDataHandler *dh, GdaValueType type)
 	gtk_container_add (GTK_CONTAINER (bbox), button);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				      gnome_db_data_entry_get_attributes (GNOME_DB_DATA_ENTRY (wid)) & 
-				      GNOME_DB_VALUE_CAN_BE_DEFAULT);
+				      GDA_VALUE_ATTR_CAN_BE_DEFAULT);
 
 	button = gtk_toggle_button_new_with_label (_("Actions?"));
 	g_signal_connect (G_OBJECT (button), "toggled",
@@ -293,11 +292,11 @@ build_main (GnomeDbDict *dict, GnomeDbDataHandler *dh, GdaValueType type)
 	gtk_container_add (GTK_CONTAINER (bbox), button);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				      gnome_db_data_entry_get_attributes (GNOME_DB_DATA_ENTRY (wid)) & 
-				      GNOME_DB_VALUE_ACTIONS_SHOWN);
+				      GDA_VALUE_ATTR_ACTIONS_SHOWN);
 	gtk_widget_show_all (bbox);
 
 	/* to set the original value */
-	entry = GTK_WIDGET (gnome_db_data_handler_get_entry_from_value (dh, NULL, type));
+	entry = GTK_WIDGET (gnome_db_util_new_data_entry (NULL, type, NULL));
 	gtk_table_attach (GTK_TABLE (table), entry, 0, 1, 5, 6, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 	gtk_widget_show (entry);
 	button = gtk_button_new_with_label (_("Set as original"));
@@ -308,7 +307,7 @@ build_main (GnomeDbDict *dict, GnomeDbDataHandler *dh, GdaValueType type)
 			  G_CALLBACK (orig_clicked_cb), wid);
 
 	/* to set the default value */
-	entry = GTK_WIDGET (gnome_db_data_handler_get_entry_from_value (dh, NULL, type));
+	entry = GTK_WIDGET (gnome_db_util_new_data_entry (NULL, type, NULL));
 	gtk_table_attach (GTK_TABLE (table), entry, 0, 1, 6, 7, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 	gtk_widget_show (entry);
 	button = gtk_button_new_with_label (_("Set as default"));
@@ -334,13 +333,13 @@ null_toggled_cb (GtkToggleButton *button, GtkWidget *entry)
 {
 	guint action = 0;
 	if (gtk_toggle_button_get_active (button))
-		action = GNOME_DB_VALUE_CAN_BE_NULL;
+		action = GDA_VALUE_ATTR_CAN_BE_NULL;
 
 	gnome_db_data_entry_set_attributes (GNOME_DB_DATA_ENTRY (entry),
-				      action, GNOME_DB_VALUE_CAN_BE_NULL);
+				      action, GDA_VALUE_ATTR_CAN_BE_NULL);
 	gtk_toggle_button_set_active (button,
 				      gnome_db_data_entry_get_attributes (GNOME_DB_DATA_ENTRY (entry)) & 
-				      GNOME_DB_VALUE_CAN_BE_NULL);
+				      GDA_VALUE_ATTR_CAN_BE_NULL);
 }
 
 void
@@ -348,13 +347,13 @@ default_toggled_cb (GtkToggleButton *button, GtkWidget *entry)
 {
 	guint action = 0;
 	if (gtk_toggle_button_get_active (button))
-		action = GNOME_DB_VALUE_CAN_BE_DEFAULT;
+		action = GDA_VALUE_ATTR_CAN_BE_DEFAULT;
 
 	gnome_db_data_entry_set_attributes (GNOME_DB_DATA_ENTRY (entry),
-				      action, GNOME_DB_VALUE_CAN_BE_DEFAULT);
+				      action, GDA_VALUE_ATTR_CAN_BE_DEFAULT);
 	gtk_toggle_button_set_active (button,
 				      gnome_db_data_entry_get_attributes (GNOME_DB_DATA_ENTRY (entry)) & 
-				      GNOME_DB_VALUE_CAN_BE_DEFAULT);
+				      GDA_VALUE_ATTR_CAN_BE_DEFAULT);
 }
 
 void
@@ -362,13 +361,13 @@ actions_toggled_cb (GtkToggleButton *button, GtkWidget *entry)
 {
 	guint action = 0;
 	if (gtk_toggle_button_get_active (button))
-		action = GNOME_DB_VALUE_ACTIONS_SHOWN;
+		action = GDA_VALUE_ATTR_ACTIONS_SHOWN;
 
 	gnome_db_data_entry_set_attributes (GNOME_DB_DATA_ENTRY (entry),
-				      action, GNOME_DB_VALUE_ACTIONS_SHOWN);
+				      action, GDA_VALUE_ATTR_ACTIONS_SHOWN);
 	gtk_toggle_button_set_active (button,
 				      gnome_db_data_entry_get_attributes (GNOME_DB_DATA_ENTRY (entry)) & 
-				      GNOME_DB_VALUE_ACTIONS_SHOWN);
+				      GDA_VALUE_ATTR_ACTIONS_SHOWN);
 }
 
 void 
@@ -377,20 +376,19 @@ entry_contents_modified (GtkWidget *entry, gpointer data)
 	guint attrs;
 	GtkLabel *label;
 	GString *str = g_string_new ("");
-	gchar *strval;
-	GdaValue *value;
-	GnomeDbDataHandler *dh;
+	GValue *value;
+	GdaDataHandler *dh;
 
 	/* flags */
 	label = g_object_get_data (G_OBJECT (entry), "flags");
 	attrs = gnome_db_data_entry_get_attributes (GNOME_DB_DATA_ENTRY (entry));
-	if (attrs & GNOME_DB_VALUE_IS_NULL)
+	if (attrs & GDA_VALUE_ATTR_IS_NULL)
 		g_string_append (str, "N ");
-	if (attrs & GNOME_DB_VALUE_IS_DEFAULT)
+	if (attrs & GDA_VALUE_ATTR_IS_DEFAULT)
 		g_string_append (str, "D ");
-	if (!(attrs & GNOME_DB_VALUE_IS_UNCHANGED))
+	if (!(attrs & GDA_VALUE_ATTR_IS_UNCHANGED))
 		g_string_append (str, "M ");
-	if (attrs & GNOME_DB_VALUE_DATA_NON_VALID)
+	if (attrs & GDA_VALUE_ATTR_DATA_NON_VALID)
 		g_string_append (str, "U ");
 
 	gtk_label_set_text (label, str->str);
@@ -400,26 +398,29 @@ entry_contents_modified (GtkWidget *entry, gpointer data)
 	label = g_object_get_data (G_OBJECT (entry), "value");
 	value = gnome_db_data_entry_get_value (GNOME_DB_DATA_ENTRY (entry));
 	dh = gnome_db_data_entry_get_handler (GNOME_DB_DATA_ENTRY (entry));
-	strval = gnome_db_data_handler_get_sql_from_value (dh, value);
-	gda_value_free (value);
-	gtk_label_set_text (label, strval);
-	g_free (strval);
+	if (dh) {
+		gchar *strval;
+		strval = gda_data_handler_get_sql_from_value (dh, value);
+		gda_value_free (value);
+		gtk_label_set_text (label, strval);
+		g_free (strval);
+	}
 }
 
 void
 orig_clicked_cb (GtkButton *button, GtkWidget *entry)
 {
 	GtkWidget *wid;
-	GdaValue *value;
+	GValue *value;
 
 	wid = g_object_get_data (G_OBJECT (button), "entry");
 	value = gnome_db_data_entry_get_value (GNOME_DB_DATA_ENTRY (wid));
 	g_print ("Setting to original Value %p ", value);
 	if (value) {
-		if (gda_value_get_type (value) == GDA_VALUE_TYPE_NULL)
-			g_print ("GDA_VALUE_TYPE_NULL\n");
+		if (G_VALUE_TYPE (value) == GDA_TYPE_NULL)
+			g_print ("GDA_TYPE_NULL\n");
 		else
-			g_print ("type = %d\n", gda_value_get_type (value));
+			g_print ("type = %d\n", G_VALUE_TYPE (value));
 	}
 	
 	gnome_db_data_entry_set_value_orig (GNOME_DB_DATA_ENTRY (entry), value);
@@ -430,7 +431,7 @@ void
 default_clicked_cb (GtkButton *button, GtkWidget *entry)
 {
 	GtkWidget *wid;
-	GdaValue *value;
+	GValue *value;
 
 	wid = g_object_get_data (G_OBJECT (button), "entry");
 	value = gnome_db_data_entry_get_value (GNOME_DB_DATA_ENTRY (wid));
